Index: wp-admin/includes/meta-boxes.php
===================================================================
--- wp-admin/includes/meta-boxes.php	(revision 43719)
+++ wp-admin/includes/meta-boxes.php	(working copy)
@@ -492,7 +492,7 @@
 	} else {
 		$args = $box['args'];
 	}
-	$r                     = wp_parse_args( $args, $defaults );
+	$parsed_args                    = wp_parse_args( $args, $defaults );
 	$tax_name              = esc_attr( $r['taxonomy'] );
 	$taxonomy              = get_taxonomy( $r['taxonomy'] );
 	$user_can_assign_terms = current_user_can( $taxonomy->cap->assign_terms );
@@ -555,7 +555,7 @@
 	} else {
 		$args = $box['args'];
 	}
-	$r        = wp_parse_args( $args, $defaults );
+	$parsed_args       = wp_parse_args( $args, $defaults );
 	$tax_name = esc_attr( $r['taxonomy'] );
 	$taxonomy = get_taxonomy( $r['taxonomy'] );
 	?>
@@ -1310,12 +1310,12 @@
 		<th scope="row"><label for="link_rating"><?php _e( 'Rating' ); ?></label></th>
 		<td><select name="link_rating" id="link_rating" size="1">
 		<?php
-		for ( $r = 0; $r <= 10; $r++ ) {
-			echo '<option value="' . $r . '"';
-			if ( isset( $link->link_rating ) && $link->link_rating == $r ) {
+		for ( $parsed_args= 0; $parsed_args<= 10; $r++ ) {
+			echo '<option value="' . $parsed_args. '"';
+			if ( isset( $link->link_rating ) && $link->link_rating == $parsed_args) {
 				echo ' selected="selected"';
 			}
-			echo( '>' . $r . '</option>' );
+			echo( '>' . $parsed_args. '</option>' );
 		}
 		?>
 		</select>&nbsp;<?php _e( '(Leave at 0 for no rating.)' ); ?>
Index: wp-admin/includes/ms.php
===================================================================
--- wp-admin/includes/ms.php	(revision 43719)
+++ wp-admin/includes/ms.php	(working copy)
@@ -1091,7 +1091,7 @@
 	);
 
 	// Parse arguments
-	$r = wp_parse_args(
+	$parsed_args = wp_parse_args(
 		$args,
 		array(
 			'blog_id'  => isset( $_GET['blog_id'] ) ? (int) $_GET['blog_id'] : 0,
@@ -1104,10 +1104,10 @@
 	$screen_links = array();
 
 	// Loop through tabs
-	foreach ( $r['links'] as $link_id => $link ) {
+	foreach ( $parsed_args['links'] as $link_id => $link ) {
 
 		// Skip link if user can't access
-		if ( ! current_user_can( $link['cap'], $r['blog_id'] ) ) {
+		if ( ! current_user_can( $link['cap'], $parsed_args['blog_id'] ) ) {
 			continue;
 		}
 
@@ -1115,7 +1115,7 @@
 		$classes = array( 'nav-tab' );
 
 		// Selected is set by the parent OR assumed by the $pagenow global
-		if ( $r['selected'] === $link_id || $link['url'] === $GLOBALS['pagenow'] ) {
+		if ( $parsed_args['selected'] === $link_id || $link['url'] === $GLOBALS['pagenow'] ) {
 			$classes[] = 'nav-tab-active';
 		}
 
@@ -1123,7 +1123,7 @@
 		$esc_classes = implode( ' ', $classes );
 
 		// Get the URL for this link
-		$url = add_query_arg( array( 'id' => $r['blog_id'] ), network_admin_url( $link['url'] ) );
+		$url = add_query_arg( array( 'id' => $parsed_args['blog_id'] ), network_admin_url( $link['url'] ) );
 
 		// Add link to nav links
 		$screen_links[ $link_id ] = '<a href="' . esc_url( $url ) . '" id="' . esc_attr( $link_id ) . '" class="' . $esc_classes . '">' . esc_html( $link['label'] ) . '</a>';
Index: wp-admin/includes/template.php
===================================================================
--- wp-admin/includes/template.php	(revision 43719)
+++ wp-admin/includes/template.php	(working copy)
@@ -100,16 +100,16 @@
 	 */
 	$params = apply_filters( 'wp_terms_checklist_args', $args, $post_id );
 
-	$r = wp_parse_args( $params, $defaults );
+	$parsed_args = wp_parse_args( $params, $defaults );
 
-	if ( empty( $r['walker'] ) || ! ( $r['walker'] instanceof Walker ) ) {
+	if ( empty( $parsed_args['walker'] ) || ! ( $parsed_args['walker'] instanceof Walker ) ) {
 		$walker = new Walker_Category_Checklist;
 	} else {
-		$walker = $r['walker'];
+		$walker = $parsed_args['walker'];
 	}
 
-	$taxonomy             = $r['taxonomy'];
-	$descendants_and_self = (int) $r['descendants_and_self'];
+	$taxonomy             = $parsed_args['taxonomy'];
+	$descendants_and_self = (int) $parsed_args['descendants_and_self'];
 
 	$args = array( 'taxonomy' => $taxonomy );
 
@@ -116,17 +116,17 @@
 	$tax              = get_taxonomy( $taxonomy );
 	$args['disabled'] = ! current_user_can( $tax->cap->assign_terms );
 
-	$args['list_only'] = ! empty( $r['list_only'] );
+	$args['list_only'] = ! empty( $parsed_args['list_only'] );
 
-	if ( is_array( $r['selected_cats'] ) ) {
-		$args['selected_cats'] = $r['selected_cats'];
+	if ( is_array( $parsed_args['selected_cats'] ) ) {
+		$args['selected_cats'] = $parsed_args['selected_cats'];
 	} elseif ( $post_id ) {
 		$args['selected_cats'] = wp_get_object_terms( $post_id, $taxonomy, array_merge( $args, array( 'fields' => 'ids' ) ) );
 	} else {
 		$args['selected_cats'] = array();
 	}
-	if ( is_array( $r['popular_cats'] ) ) {
-		$args['popular_cats'] = $r['popular_cats'];
+	if ( is_array( $parsed_args['popular_cats'] ) ) {
+		$args['popular_cats'] = $parsed_args['popular_cats'];
 	} else {
 		$args['popular_cats'] = get_terms(
 			$taxonomy,
@@ -156,7 +156,7 @@
 
 	$output = '';
 
-	if ( $r['checked_ontop'] ) {
+	if ( $parsed_args['checked_ontop'] ) {
 		// Post process $categories rather than adding an exclude to the get_terms() query to keep the query the same across all posts (for any query cache)
 		$checked_categories = array();
 		$keys               = array_keys( $categories );
@@ -174,7 +174,7 @@
 	// Then the rest of them
 	$output .= call_user_func_array( array( $walker, 'walk' ), array( $categories, 0, $args ) );
 
-	if ( $r['echo'] ) {
+	if ( $parsed_args['echo'] ) {
 		echo $output;
 	}
 
@@ -2301,13 +2301,13 @@
 		'number' => 0,
 		'echo'   => true,
 	);
-	$r        = wp_parse_args( $args, $defaults );
+	$parsed_args        = wp_parse_args( $args, $defaults );
 
 	// Non-English decimal places when the $rating is coming from a string
-	$rating = (float) str_replace( ',', '.', $r['rating'] );
+	$rating = (float) str_replace( ',', '.', $parsed_args['rating'] );
 
 	// Convert Percentage to star rating, 0..5 in .5 increments
-	if ( 'percent' === $r['type'] ) {
+	if ( 'percent' === $parsed_args['type'] ) {
 		$rating = round( $rating / 10, 0 ) / 2;
 	}
 
@@ -2316,10 +2316,10 @@
 	$half_stars  = ceil( $rating - $full_stars );
 	$empty_stars = 5 - $full_stars - $half_stars;
 
-	if ( $r['number'] ) {
+	if ( $parsed_args['number'] ) {
 		/* translators: 1: the rating, 2: the number of ratings */
-		$format = _n( '%1$s rating based on %2$s rating', '%1$s rating based on %2$s ratings', $r['number'] );
-		$title  = sprintf( $format, number_format_i18n( $rating, 1 ), number_format_i18n( $r['number'] ) );
+		$format = _n( '%1$s rating based on %2$s rating', '%1$s rating based on %2$s ratings', $parsed_args['number'] );
+		$title  = sprintf( $format, number_format_i18n( $rating, 1 ), number_format_i18n( $parsed_args['number'] ) );
 	} else {
 		/* translators: %s: the rating */
 		$title = sprintf( __( '%s rating' ), number_format_i18n( $rating, 1 ) );
@@ -2332,7 +2332,7 @@
 	$output .= str_repeat( '<div class="star star-empty" aria-hidden="true"></div>', $empty_stars );
 	$output .= '</div>';
 
-	if ( $r['echo'] ) {
+	if ( $parsed_args['echo'] ) {
 		echo $output;
 	}
 
Index: wp-includes/bookmark-template.php
===================================================================
--- wp-includes/bookmark-template.php	(revision 43719)
+++ wp-includes/bookmark-template.php	(working copy)
@@ -62,7 +62,7 @@
 		'link_after'       => '',
 	);
 
-	$r = wp_parse_args( $args, $defaults );
+	$parsed_args = wp_parse_args( $args, $defaults );
 
 	$output = ''; // Blank string to start with.
 
@@ -70,8 +70,8 @@
 		if ( ! isset( $bookmark->recently_updated ) ) {
 			$bookmark->recently_updated = false;
 		}
-		$output .= $r['before'];
-		if ( $r['show_updated'] && $bookmark->recently_updated ) {
+		$output .= $parsed_args['before'];
+		if ( $parsed_args['show_updated'] && $bookmark->recently_updated ) {
 			$output .= '<em>';
 		}
 		$the_link = '#';
@@ -82,7 +82,7 @@
 		$name  = esc_attr( sanitize_bookmark_field( 'link_name', $bookmark->link_name, $bookmark->link_id, 'display' ) );
 		$title = $desc;
 
-		if ( $r['show_updated'] ) {
+		if ( $parsed_args['show_updated'] ) {
 			if ( '00' != substr( $bookmark->link_updated_f, 0, 2 ) ) {
 				$title .= ' (';
 				$title .= sprintf(
@@ -95,7 +95,7 @@
 				$title .= ')';
 			}
 		}
-		$alt = ' alt="' . $name . ( $r['show_description'] ? ' ' . $title : '' ) . '"';
+		$alt = ' alt="' . $name . ( $parsed_args['show_description'] ? ' ' . $title : '' ) . '"';
 
 		if ( '' != $title ) {
 			$title = ' title="' . $title . '"';
@@ -110,15 +110,15 @@
 		}
 		$output .= '<a href="' . $the_link . '"' . $rel . $title . $target . '>';
 
-		$output .= $r['link_before'];
+		$output .= $parsed_args['link_before'];
 
-		if ( $bookmark->link_image != null && $r['show_images'] ) {
+		if ( $bookmark->link_image != null && $parsed_args['show_images'] ) {
 			if ( strpos( $bookmark->link_image, 'http' ) === 0 ) {
 				$output .= "<img src=\"$bookmark->link_image\" $alt $title />";
 			} else { // If it's a relative path
 				$output .= '<img src="' . get_option( 'siteurl' ) . "$bookmark->link_image\" $alt $title />";
 			}
-			if ( $r['show_name'] ) {
+			if ( $parsed_args['show_name'] ) {
 				$output .= " $name";
 			}
 		} else {
@@ -125,20 +125,20 @@
 			$output .= $name;
 		}
 
-		$output .= $r['link_after'];
+		$output .= $parsed_args['link_after'];
 
 		$output .= '</a>';
 
-		if ( $r['show_updated'] && $bookmark->recently_updated ) {
+		if ( $parsed_args['show_updated'] && $bookmark->recently_updated ) {
 			$output .= '</em>';
 		}
 
-		if ( $r['show_description'] && '' != $desc ) {
-			$output .= $r['between'] . $desc;
+		if ( $parsed_args['show_description'] && '' != $desc ) {
+			$output .= $parsed_args['between'] . $desc;
 		}
 
-		if ( $r['show_rating'] ) {
-			$output .= $r['between'] . sanitize_bookmark_field(
+		if ( $parsed_args['show_rating'] ) {
+			$output .= $parsed_args['between'] . sanitize_bookmark_field(
 				'link_rating',
 				$bookmark->link_rating,
 				$bookmark->link_id,
@@ -145,7 +145,7 @@
 				'display'
 			);
 		}
-		$output .= $r['after'] . "\n";
+		$output .= $parsed_args['after'] . "\n";
 	} // end while
 
 	return $output;
@@ -225,37 +225,37 @@
 		'category_after'   => '</li>',
 	);
 
-	$r = wp_parse_args( $args, $defaults );
+	$parsed_args = wp_parse_args( $args, $defaults );
 
 	$output = '';
 
-	if ( ! is_array( $r['class'] ) ) {
-		$r['class'] = explode( ' ', $r['class'] );
+	if ( ! is_array( $parsed_args['class'] ) ) {
+		$parsed_args['class'] = explode( ' ', $parsed_args['class'] );
 	}
-	$r['class'] = array_map( 'sanitize_html_class', $r['class'] );
-	$r['class'] = trim( join( ' ', $r['class'] ) );
+	$parsed_args['class'] = array_map( 'sanitize_html_class', $parsed_args['class'] );
+	$parsed_args['class'] = trim( join( ' ', $parsed_args['class'] ) );
 
-	if ( $r['categorize'] ) {
+	if ( $parsed_args['categorize'] ) {
 		$cats = get_terms(
 			'link_category',
 			array(
-				'name__like'   => $r['category_name'],
-				'include'      => $r['category'],
-				'exclude'      => $r['exclude_category'],
-				'orderby'      => $r['category_orderby'],
-				'order'        => $r['category_order'],
+				'name__like'   => $parsed_args['category_name'],
+				'include'      => $parsed_args['category'],
+				'exclude'      => $parsed_args['exclude_category'],
+				'orderby'      => $parsed_args['category_orderby'],
+				'order'        => $parsed_args['category_order'],
 				'hierarchical' => 0,
 			)
 		);
 		if ( empty( $cats ) ) {
-			$r['categorize'] = false;
+			$parsed_args['categorize'] = false;
 		}
 	}
 
-	if ( $r['categorize'] ) {
+	if ( $parsed_args['categorize'] ) {
 		// Split the bookmarks into ul's for each category
 		foreach ( (array) $cats as $cat ) {
-			$params    = array_merge( $r, array( 'category' => $cat->term_id ) );
+			$params    = array_merge( $parsed_args, array( 'category' => $cat->term_id ) );
 			$bookmarks = get_bookmarks( $params );
 			if ( empty( $bookmarks ) ) {
 				continue;
@@ -262,8 +262,8 @@
 			}
 			$output .= str_replace(
 				array( '%id', '%class' ),
-				array( "linkcat-$cat->term_id", $r['class'] ),
-				$r['category_before']
+				array( "linkcat-$cat->term_id", $parsed_args['class'] ),
+				$parsed_args['category_before']
 			);
 			/**
 			 * Filters the bookmarks category name.
@@ -274,34 +274,34 @@
 			 */
 			$catname = apply_filters( 'link_category', $cat->name );
 
-			$output .= $r['title_before'];
+			$output .= $parsed_args['title_before'];
 			$output .= $catname;
-			$output .= $r['title_after'];
+			$output .= $parsed_args['title_after'];
 			$output .= "\n\t<ul class='xoxo blogroll'>\n";
-			$output .= _walk_bookmarks( $bookmarks, $r );
+			$output .= _walk_bookmarks( $bookmarks, $parsed_args );
 			$output .= "\n\t</ul>\n";
-			$output .= $r['category_after'] . "\n";
+			$output .= $parsed_args['category_after'] . "\n";
 		}
 	} else {
 		//output one single list using title_li for the title
-		$bookmarks = get_bookmarks( $r );
+		$bookmarks = get_bookmarks( $parsed_args );
 
 		if ( ! empty( $bookmarks ) ) {
-			if ( ! empty( $r['title_li'] ) ) {
+			if ( ! empty( $parsed_args['title_li'] ) ) {
 				$output .= str_replace(
 					array( '%id', '%class' ),
-					array( 'linkcat-' . $r['category'], $r['class'] ),
-					$r['category_before']
+					array( 'linkcat-' . $parsed_args['category'], $parsed_args['class'] ),
+					$parsed_args['category_before']
 				);
-				$output .= $r['title_before'];
-				$output .= $r['title_li'];
-				$output .= $r['title_after'];
+				$output .= $parsed_args['title_before'];
+				$output .= $parsed_args['title_li'];
+				$output .= $parsed_args['title_after'];
 				$output .= "\n\t<ul class='xoxo blogroll'>\n";
-				$output .= _walk_bookmarks( $bookmarks, $r );
+				$output .= _walk_bookmarks( $bookmarks, $parsed_args );
 				$output .= "\n\t</ul>\n";
-				$output .= $r['category_after'] . "\n";
+				$output .= $parsed_args['category_after'] . "\n";
 			} else {
-				$output .= _walk_bookmarks( $bookmarks, $r );
+				$output .= _walk_bookmarks( $bookmarks, $parsed_args );
 			}
 		}
 	}
@@ -315,7 +315,7 @@
 	 */
 	$html = apply_filters( 'wp_list_bookmarks', $output );
 
-	if ( ! $r['echo'] ) {
+	if ( ! $parsed_args['echo'] ) {
 		return $html;
 	}
 	echo $html;
Index: wp-includes/class-wp-ajax-response.php
===================================================================
--- wp-includes/class-wp-ajax-response.php	(revision 43719)
+++ wp-includes/class-wp-ajax-response.php	(working copy)
@@ -73,14 +73,14 @@
 			'supplemental' => array(),
 		);
 
-		$r = wp_parse_args( $args, $defaults );
+		$parsed_args = wp_parse_args( $args, $defaults );
 
-		$position = preg_replace( '/[^a-z0-9:_-]/i', '', $r['position'] );
-		$id       = $r['id'];
-		$what     = $r['what'];
-		$action   = $r['action'];
-		$old_id   = $r['old_id'];
-		$data     = $r['data'];
+		$position = preg_replace( '/[^a-z0-9:_-]/i', '', $parsed_args['position'] );
+		$id       = $parsed_args['id'];
+		$what     = $parsed_args['what'];
+		$action   = $parsed_args['action'];
+		$old_id   = $parsed_args['old_id'];
+		$data     = $parsed_args['data'];
 
 		if ( is_wp_error( $id ) ) {
 			$data = $id;
@@ -117,8 +117,8 @@
 		}
 
 		$s = '';
-		if ( is_array( $r['supplemental'] ) ) {
-			foreach ( $r['supplemental'] as $k => $v ) {
+		if ( is_array( $parsed_args['supplemental'] ) ) {
+			foreach ( $parsed_args['supplemental'] as $k => $v ) {
 				$s .= "<$k><![CDATA[$v]]></$k>";
 			}
 			$s = "<supplemental>$s</supplemental>";
Index: wp-includes/class-wp-http-streams.php
===================================================================
--- wp-includes/class-wp-http-streams.php	(revision 43719)
+++ wp-includes/class-wp-http-streams.php	(working copy)
@@ -38,18 +38,18 @@
 			'cookies'     => array(),
 		);
 
-		$r = wp_parse_args( $args, $defaults );
+		$parsed_args = wp_parse_args( $args, $defaults );
 
-		if ( isset( $r['headers']['User-Agent'] ) ) {
-			$r['user-agent'] = $r['headers']['User-Agent'];
-			unset( $r['headers']['User-Agent'] );
-		} elseif ( isset( $r['headers']['user-agent'] ) ) {
-			$r['user-agent'] = $r['headers']['user-agent'];
-			unset( $r['headers']['user-agent'] );
+		if ( isset( $parsed_args['headers']['User-Agent'] ) ) {
+			$parsed_args['user-agent'] = $parsed_args['headers']['User-Agent'];
+			unset( $parsed_args['headers']['User-Agent'] );
+		} elseif ( isset( $parsed_args['headers']['user-agent'] ) ) {
+			$parsed_args['user-agent'] = $parsed_args['headers']['user-agent'];
+			unset( $parsed_args['headers']['user-agent'] );
 		}
 
 		// Construct Cookie: header if any cookies are set.
-		WP_Http::buildCookieHeader( $r );
+		WP_Http::buildCookieHeader( $parsed_args );
 
 		$arrURL = parse_url( $url );
 
@@ -70,13 +70,13 @@
 			$arrURL['path'] = '/';
 		}
 
-		if ( isset( $r['headers']['Host'] ) || isset( $r['headers']['host'] ) ) {
-			if ( isset( $r['headers']['Host'] ) ) {
-				$arrURL['host'] = $r['headers']['Host'];
+		if ( isset( $parsed_args['headers']['Host'] ) || isset( $parsed_args['headers']['host'] ) ) {
+			if ( isset( $parsed_args['headers']['Host'] ) ) {
+				$arrURL['host'] = $parsed_args['headers']['Host'];
 			} else {
-				$arrURL['host'] = $r['headers']['host'];
+				$arrURL['host'] = $parsed_args['headers']['host'];
 			}
-			unset( $r['headers']['Host'], $r['headers']['host'] );
+			unset( $parsed_args['headers']['Host'], $parsed_args['headers']['host'] );
 		}
 
 		/*
@@ -90,8 +90,8 @@
 
 		$connect_host = $secure_transport ? 'ssl://' . $connect_host : 'tcp://' . $connect_host;
 
-		$is_local   = isset( $r['local'] ) && $r['local'];
-		$ssl_verify = isset( $r['sslverify'] ) && $r['sslverify'];
+		$is_local   = isset( $parsed_args['local'] ) && $parsed_args['local'];
+		$ssl_verify = isset( $parsed_args['sslverify'] ) && $parsed_args['sslverify'];
 		if ( $is_local ) {
 			/**
 			 * Filters whether SSL should be verified for local requests.
@@ -117,14 +117,14 @@
 					//'CN_match' => $arrURL['host'], // This is handled by self::verify_ssl_certificate()
 					'capture_peer_cert' => $ssl_verify,
 					'SNI_enabled'       => true,
-					'cafile'            => $r['sslcertificates'],
+					'cafile'            => $parsed_args['sslcertificates'],
 					'allow_self_signed' => ! $ssl_verify,
 				),
 			)
 		);
 
-		$timeout         = (int) floor( $r['timeout'] );
-		$utimeout        = $timeout == $r['timeout'] ? 0 : 1000000 * $r['timeout'] % 1000000;
+		$timeout         = (int) floor( $parsed_args['timeout'] );
+		$utimeout        = $timeout == $parsed_args['timeout'] ? 0 : 1000000 * $parsed_args['timeout'] % 1000000;
 		$connect_timeout = max( $timeout, 1 );
 
 		// Store error number.
@@ -180,7 +180,7 @@
 			$requestPath = $arrURL['path'] . ( isset( $arrURL['query'] ) ? '?' . $arrURL['query'] : '' );
 		}
 
-		$strHeaders = strtoupper( $r['method'] ) . ' ' . $requestPath . ' HTTP/' . $r['httpversion'] . "\r\n";
+		$strHeaders = strtoupper( $parsed_args['method'] ) . ' ' . $requestPath . ' HTTP/' . $parsed_args['httpversion'] . "\r\n";
 
 		$include_port_in_host_header = (
 			( $proxy->is_enabled() && $proxy->send_through_proxy( $url ) ) ||
@@ -194,16 +194,16 @@
 			$strHeaders .= 'Host: ' . $arrURL['host'] . "\r\n";
 		}
 
-		if ( isset( $r['user-agent'] ) ) {
-			$strHeaders .= 'User-agent: ' . $r['user-agent'] . "\r\n";
+		if ( isset( $parsed_args['user-agent'] ) ) {
+			$strHeaders .= 'User-agent: ' . $parsed_args['user-agent'] . "\r\n";
 		}
 
-		if ( is_array( $r['headers'] ) ) {
-			foreach ( (array) $r['headers'] as $header => $headerValue ) {
+		if ( is_array( $parsed_args['headers'] ) ) {
+			foreach ( (array) $parsed_args['headers'] as $header => $headerValue ) {
 				$strHeaders .= $header . ': ' . $headerValue . "\r\n";
 			}
 		} else {
-			$strHeaders .= $r['headers'];
+			$strHeaders .= $parsed_args['headers'];
 		}
 
 		if ( $proxy->use_authentication() ) {
@@ -212,13 +212,13 @@
 
 		$strHeaders .= "\r\n";
 
-		if ( ! is_null( $r['body'] ) ) {
-			$strHeaders .= $r['body'];
+		if ( ! is_null( $parsed_args['body'] ) ) {
+			$strHeaders .= $parsed_args['body'];
 		}
 
 		fwrite( $handle, $strHeaders );
 
-		if ( ! $r['blocking'] ) {
+		if ( ! $parsed_args['blocking'] ) {
 			stream_set_blocking( $handle, 0 );
 			fclose( $handle );
 			return array(
@@ -236,16 +236,16 @@
 		$bodyStarted  = false;
 		$keep_reading = true;
 		$block_size   = 4096;
-		if ( isset( $r['limit_response_size'] ) ) {
-			$block_size = min( $block_size, $r['limit_response_size'] );
+		if ( isset( $parsed_args['limit_response_size'] ) ) {
+			$block_size = min( $block_size, $parsed_args['limit_response_size'] );
 		}
 
 		// If streaming to a file setup the file handle.
-		if ( $r['stream'] ) {
+		if ( $parsed_args['stream'] ) {
 			if ( ! WP_DEBUG ) {
-				$stream_handle = @fopen( $r['filename'], 'w+' );
+				$stream_handle = @fopen( $parsed_args['filename'], 'w+' );
 			} else {
-				$stream_handle = fopen( $r['filename'], 'w+' );
+				$stream_handle = fopen( $parsed_args['filename'], 'w+' );
 			}
 			if ( ! $stream_handle ) {
 				return new WP_Error(
@@ -254,7 +254,7 @@
 						/* translators: 1: fopen(), 2: file name */
 						__( 'Could not open handle for %1$s to %2$s.' ),
 						'fopen()',
-						$r['filename']
+						$parsed_args['filename']
 					)
 				);
 			}
@@ -275,8 +275,8 @@
 
 				$this_block_size = strlen( $block );
 
-				if ( isset( $r['limit_response_size'] ) && ( $bytes_written + $this_block_size ) > $r['limit_response_size'] ) {
-					$this_block_size = ( $r['limit_response_size'] - $bytes_written );
+				if ( isset( $parsed_args['limit_response_size'] ) && ( $bytes_written + $this_block_size ) > $parsed_args['limit_response_size'] ) {
+					$this_block_size = ( $parsed_args['limit_response_size'] - $bytes_written );
 					$block           = substr( $block, 0, $this_block_size );
 				}
 
@@ -290,7 +290,7 @@
 
 				$bytes_written += $bytes_written_to_file;
 
-				$keep_reading = ! isset( $r['limit_response_size'] ) || $bytes_written < $r['limit_response_size'];
+				$keep_reading = ! isset( $parsed_args['limit_response_size'] ) || $bytes_written < $parsed_args['limit_response_size'];
 			}
 
 			fclose( $stream_handle );
@@ -304,7 +304,7 @@
 					$header_length = strpos( $strResponse, "\r\n\r\n" ) + 4;
 					$bodyStarted   = true;
 				}
-				$keep_reading = ( ! $bodyStarted || ! isset( $r['limit_response_size'] ) || strlen( $strResponse ) < ( $header_length + $r['limit_response_size'] ) );
+				$keep_reading = ( ! $bodyStarted || ! isset( $parsed_args['limit_response_size'] ) || strlen( $strResponse ) < ( $header_length + $parsed_args['limit_response_size'] ) );
 			}
 
 			$process = WP_Http::processResponse( $strResponse );
@@ -322,11 +322,11 @@
 			'body'     => null,
 			'response' => $arrHeaders['response'],
 			'cookies'  => $arrHeaders['cookies'],
-			'filename' => $r['filename'],
+			'filename' => $parsed_args['filename'],
 		);
 
 		// Handle redirects.
-		if ( false !== ( $redirect_response = WP_Http::handle_redirects( $url, $r, $response ) ) ) {
+		if ( false !== ( $redirect_response = WP_Http::handle_redirects( $url, $parsed_args, $response ) ) ) {
 			return $redirect_response;
 		}
 
@@ -335,12 +335,12 @@
 			$process['body'] = WP_Http::chunkTransferDecode( $process['body'] );
 		}
 
-		if ( true === $r['decompress'] && true === WP_Http_Encoding::should_decode( $arrHeaders['headers'] ) ) {
+		if ( true === $parsed_args['decompress'] && true === WP_Http_Encoding::should_decode( $arrHeaders['headers'] ) ) {
 			$process['body'] = WP_Http_Encoding::decompress( $process['body'] );
 		}
 
-		if ( isset( $r['limit_response_size'] ) && strlen( $process['body'] ) > $r['limit_response_size'] ) {
-			$process['body'] = substr( $process['body'], 0, $r['limit_response_size'] );
+		if ( isset( $parsed_args['limit_response_size'] ) && strlen( $process['body'] ) > $parsed_args['limit_response_size'] ) {
+			$process['body'] = substr( $process['body'], 0, $parsed_args['limit_response_size'] );
 		}
 
 		$response['body'] = $process['body'];
Index: wp-includes/comment.php
===================================================================
--- wp-includes/comment.php	(revision 43719)
+++ wp-includes/comment.php	(working copy)
@@ -168,10 +168,10 @@
 		'post_id' => $post_id,
 		'order'   => 'ASC',
 	);
-	$r        = wp_parse_args( $args, $defaults );
+	$parsed_args        = wp_parse_args( $args, $defaults );
 
 	$query = new WP_Comment_Query;
-	return $query->query( $r );
+	return $query->query( $parsed_args );
 }
 
 /**
Index: wp-includes/deprecated.php
===================================================================
--- wp-includes/deprecated.php	(revision 43719)
+++ wp-includes/deprecated.php	(working copy)
@@ -430,9 +430,9 @@
 		'title_li' => '',
 	);
 
-	$r = wp_parse_args( $args, $defaults );
+	$parsed_args = wp_parse_args( $args, $defaults );
 
-	return wp_list_bookmarks($r);
+	return wp_list_bookmarks($parsed_args);
 }
 
 /**
@@ -635,24 +635,24 @@
 function wp_list_cats($args = '') {
 	_deprecated_function( __FUNCTION__, '2.1.0', 'wp_list_categories()' );
 
-	$r = wp_parse_args( $args );
+	$parsed_args = wp_parse_args( $args );
 
 	// Map to new names.
-	if ( isset($r['optionall']) && isset($r['all']))
-		$r['show_option_all'] = $r['all'];
-	if ( isset($r['sort_column']) )
-		$r['orderby'] = $r['sort_column'];
-	if ( isset($r['sort_order']) )
-		$r['order'] = $r['sort_order'];
-	if ( isset($r['optiondates']) )
-		$r['show_last_update'] = $r['optiondates'];
-	if ( isset($r['optioncount']) )
-		$r['show_count'] = $r['optioncount'];
-	if ( isset($r['list']) )
-		$r['style'] = $r['list'] ? 'list' : 'break';
-	$r['title_li'] = '';
+	if ( isset($parsed_args['optionall']) && isset($parsed_args['all']))
+		$parsed_args['show_option_all'] = $parsed_args['all'];
+	if ( isset($parsed_args['sort_column']) )
+		$parsed_args['orderby'] = $parsed_args['sort_column'];
+	if ( isset($parsed_args['sort_order']) )
+		$parsed_args['order'] = $parsed_args['sort_order'];
+	if ( isset($parsed_args['optiondates']) )
+		$parsed_args['show_last_update'] = $parsed_args['optiondates'];
+	if ( isset($parsed_args['optioncount']) )
+		$parsed_args['show_count'] = $parsed_args['optioncount'];
+	if ( isset($parsed_args['list']) )
+		$parsed_args['style'] = $parsed_args['list'] ? 'list' : 'break';
+	$parsed_args['title_li'] = '';
 
-	return wp_list_categories($r);
+	return wp_list_categories($parsed_args);
 }
 
 /**
@@ -892,9 +892,9 @@
 		'title_li' => '',
 	);
 
-	$r = wp_parse_args( $args, $defaults );
+	$parsed_args = wp_parse_args( $args, $defaults );
 
-	return wp_list_bookmarks($r);
+	return wp_list_bookmarks($parsed_args);
 }
 
 /**
Index: wp-includes/functions.php
===================================================================
--- wp-includes/functions.php	(revision 43719)
+++ wp-includes/functions.php	(working copy)
@@ -2933,7 +2933,7 @@
  */
 function _default_wp_die_handler( $message, $title = '', $args = array() ) {
 	$defaults = array( 'response' => 500 );
-	$r        = wp_parse_args( $args, $defaults );
+	$parsed_args        = wp_parse_args( $args, $defaults );
 
 	$have_gettext = function_exists( '__' );
 
@@ -2960,7 +2960,7 @@
 		$message = "<p>$message</p>";
 	}
 
-	if ( isset( $r['back_link'] ) && $r['back_link'] ) {
+	if ( isset( $parsed_args['back_link'] ) && $parsed_args['back_link'] ) {
 		$back_text = $have_gettext ? __( '&laquo; Back' ) : '&laquo; Back';
 		$message  .= "\n<p><a href='javascript:history.back()'>$back_text</a></p>";
 	}
@@ -2967,7 +2967,7 @@
 
 	if ( ! did_action( 'admin_head' ) ) :
 		if ( ! headers_sent() ) {
-			status_header( $r['response'] );
+			status_header( $parsed_args['response'] );
 			nocache_headers();
 			header( 'Content-Type: text/html; charset=utf-8' );
 		}
@@ -2977,7 +2977,7 @@
 		}
 
 		$text_direction = 'ltr';
-		if ( isset( $r['text_direction'] ) && 'rtl' == $r['text_direction'] ) {
+		if ( isset( $parsed_args['text_direction'] ) && 'rtl' == $parsed_args['text_direction'] ) {
 			$text_direction = 'rtl';
 		} elseif ( function_exists( 'is_rtl' ) && is_rtl() ) {
 			$text_direction = 'rtl';
@@ -3144,10 +3144,10 @@
 	global $wp_xmlrpc_server;
 	$defaults = array( 'response' => 500 );
 
-	$r = wp_parse_args( $args, $defaults );
+	$parsed_args = wp_parse_args( $args, $defaults );
 
 	if ( $wp_xmlrpc_server ) {
-		$error = new IXR_Error( $r['response'], $message );
+		$error = new IXR_Error( $parsed_args['response'], $message );
 		$wp_xmlrpc_server->output( $error->getXml() );
 	}
 	die();
@@ -3169,10 +3169,10 @@
 	$defaults = array(
 		'response' => 200,
 	);
-	$r        = wp_parse_args( $args, $defaults );
+	$parsed_args        = wp_parse_args( $args, $defaults );
 
-	if ( ! headers_sent() && null !== $r['response'] ) {
-		status_header( $r['response'] );
+	if ( ! headers_sent() && null !== $parsed_args['response'] ) {
+		status_header( $parsed_args['response'] );
 	}
 
 	if ( is_scalar( $message ) ) {
Index: wp-includes/post-template.php
===================================================================
--- wp-includes/post-template.php	(revision 43719)
+++ wp-includes/post-template.php	(working copy)
@@ -84,18 +84,18 @@
 		'echo'   => true,
 		'post'   => get_post(),
 	);
-	$r        = wp_parse_args( $args, $defaults );
+	$parsed_args        = wp_parse_args( $args, $defaults );
 
-	$title = get_the_title( $r['post'] );
+	$title = get_the_title( $parsed_args['post'] );
 
 	if ( strlen( $title ) == 0 ) {
 		return;
 	}
 
-	$title = $r['before'] . $title . $r['after'];
+	$title = $parsed_args['before'] . $title . $parsed_args['after'];
 	$title = esc_attr( strip_tags( $title ) );
 
-	if ( $r['echo'] ) {
+	if ( $parsed_args['echo'] ) {
 		echo $title;
 	} else {
 		return $title;
@@ -1148,29 +1148,29 @@
 		'value_field'           => 'ID',
 	);
 
-	$r = wp_parse_args( $args, $defaults );
+	$parsed_args = wp_parse_args( $args, $defaults );
 
-	$pages  = get_pages( $r );
+	$pages  = get_pages( $parsed_args );
 	$output = '';
 	// Back-compat with old system where both id and name were based on $name argument
-	if ( empty( $r['id'] ) ) {
-		$r['id'] = $r['name'];
+	if ( empty( $parsed_args['id'] ) ) {
+		$parsed_args['id'] = $parsed_args['name'];
 	}
 
 	if ( ! empty( $pages ) ) {
 		$class = '';
-		if ( ! empty( $r['class'] ) ) {
-			$class = " class='" . esc_attr( $r['class'] ) . "'";
+		if ( ! empty( $parsed_args['class'] ) ) {
+			$class = " class='" . esc_attr( $parsed_args['class'] ) . "'";
 		}
 
-		$output = "<select name='" . esc_attr( $r['name'] ) . "'" . $class . " id='" . esc_attr( $r['id'] ) . "'>\n";
-		if ( $r['show_option_no_change'] ) {
-			$output .= "\t<option value=\"-1\">" . $r['show_option_no_change'] . "</option>\n";
+		$output = "<select name='" . esc_attr( $parsed_args['name'] ) . "'" . $class . " id='" . esc_attr( $parsed_args['id'] ) . "'>\n";
+		if ( $parsed_args['show_option_no_change'] ) {
+			$output .= "\t<option value=\"-1\">" . $parsed_args['show_option_no_change'] . "</option>\n";
 		}
-		if ( $r['show_option_none'] ) {
-			$output .= "\t<option value=\"" . esc_attr( $r['option_none_value'] ) . '">' . $r['show_option_none'] . "</option>\n";
+		if ( $parsed_args['show_option_none'] ) {
+			$output .= "\t<option value=\"" . esc_attr( $parsed_args['option_none_value'] ) . '">' . $parsed_args['show_option_none'] . "</option>\n";
 		}
-		$output .= walk_page_dropdown_tree( $pages, $r['depth'], $r );
+		$output .= walk_page_dropdown_tree( $pages, $parsed_args['depth'], $parsed_args );
 		$output .= "</select>\n";
 	}
 
Index: wp-includes/taxonomy.php
===================================================================
--- wp-includes/taxonomy.php	(revision 43719)
+++ wp-includes/taxonomy.php	(working copy)
@@ -4322,9 +4322,9 @@
 		'after'  => '',
 	);
 
-	$r = wp_parse_args( $args, $defaults );
+	$parsed_args = wp_parse_args( $args, $defaults );
 
-	echo $r['before'] . join( $r['sep'], get_the_taxonomies( $r['post'], $r ) ) . $r['after'];
+	echo $parsed_args['before'] . join( $parsed_args['sep'], get_the_taxonomies( $parsed_args['post'], $parsed_args ) ) . $parsed_args['after'];
 }
 
 /**
Index: wp-includes/bookmark.php
===================================================================
--- wp-includes/bookmark.php	(revision 43719)
+++ wp-includes/bookmark.php	(working copy)
@@ -136,11 +136,11 @@
 		'search'         => '',
 	);
 
-	$r = wp_parse_args( $args, $defaults );
+	$parsed_args = wp_parse_args( $args, $defaults );
 
-	$key   = md5( serialize( $r ) );
+	$key   = md5( serialize( $parsed_args ) );
 	$cache = false;
-	if ( 'rand' !== $r['orderby'] && $cache = wp_cache_get( 'get_bookmarks', 'bookmark' ) ) {
+	if ( 'rand' !== $parsed_args['orderby'] && $cache = wp_cache_get( 'get_bookmarks', 'bookmark' ) ) {
 		if ( is_array( $cache ) && isset( $cache[ $key ] ) ) {
 			$bookmarks = $cache[ $key ];
 			/**
@@ -156,9 +156,9 @@
 			 * @see get_bookmarks()
 			 *
 			 * @param array $bookmarks List of the cached bookmarks.
 			 * @param array $r         An array of bookmark query arguments.
 			 */
-			return apply_filters( 'get_bookmarks', $bookmarks, $r );
+			return apply_filters( 'get_bookmarks', $bookmarks, $parsed_args );
 		}
 	}
 
@@ -167,11 +167,11 @@
 	}
 
 	$inclusions = '';
-	if ( ! empty( $r['include'] ) ) {
-		$r['exclude']       = '';  //ignore exclude, category, and category_name params if using include
-		$r['category']      = '';
-		$r['category_name'] = '';
-		$inclinks           = preg_split( '/[\s,]+/', $r['include'] );
+	if ( ! empty( $parsed_args['include'] ) ) {
+		$parsed_args['exclude']       = '';  //ignore exclude, category, and category_name params if using include
+		$parsed_args['category']      = '';
+		$parsed_args['category_name'] = '';
+		$inclinks           = preg_split( '/[\s,]+/', $parsed_args['include'] );
 		if ( count( $inclinks ) ) {
 			foreach ( $inclinks as $inclink ) {
 				if ( empty( $inclusions ) ) {
@@ -187,8 +187,8 @@
 	}
 
 	$exclusions = '';
-	if ( ! empty( $r['exclude'] ) ) {
-		$exlinks = preg_split( '/[\s,]+/', $r['exclude'] );
+	if ( ! empty( $parsed_args['exclude'] ) ) {
+		$exlinks = preg_split( '/[\s,]+/', $parsed_args['exclude'] );
 		if ( count( $exlinks ) ) {
 			foreach ( $exlinks as $exlink ) {
 				if ( empty( $exclusions ) ) {
@@ -203,27 +203,27 @@
 		$exclusions .= ')';
 	}
 
-	if ( ! empty( $r['category_name'] ) ) {
-		if ( $r['category'] = get_term_by( 'name', $r['category_name'], 'link_category' ) ) {
-			$r['category'] = $r['category']->term_id;
+	if ( ! empty( $parsed_args['category_name'] ) ) {
+		if ( $parsed_args['category'] = get_term_by( 'name', $parsed_args['category_name'], 'link_category' ) ) {
+			$parsed_args['category'] = $parsed_args['category']->term_id;
 		} else {
 			$cache[ $key ] = array();
 			wp_cache_set( 'get_bookmarks', $cache, 'bookmark' );
 			/** This filter is documented in wp-includes/bookmark.php */
-			return apply_filters( 'get_bookmarks', array(), $r );
+			return apply_filters( 'get_bookmarks', array(), $parsed_args );
 		}
 	}
 
 	$search = '';
-	if ( ! empty( $r['search'] ) ) {
-		$like   = '%' . $wpdb->esc_like( $r['search'] ) . '%';
+	if ( ! empty( $parsed_args['search'] ) ) {
+		$like   = '%' . $wpdb->esc_like( $parsed_args['search'] ) . '%';
 		$search = $wpdb->prepare( ' AND ( (link_url LIKE %s) OR (link_name LIKE %s) OR (link_description LIKE %s) ) ', $like, $like, $like );
 	}
 
 	$category_query = '';
 	$join           = '';
-	if ( ! empty( $r['category'] ) ) {
-		$incategories = preg_split( '/[\s,]+/', $r['category'] );
+	if ( ! empty( $parsed_args['category'] ) ) {
+		$incategories = preg_split( '/[\s,]+/', $parsed_args['category'] );
 		if ( count( $incategories ) ) {
 			foreach ( $incategories as $incat ) {
 				if ( empty( $category_query ) ) {
@@ -239,15 +239,15 @@
 		$join            = " INNER JOIN $wpdb->term_relationships AS tr ON ($wpdb->links.link_id = tr.object_id) INNER JOIN $wpdb->term_taxonomy as tt ON tt.term_taxonomy_id = tr.term_taxonomy_id";
 	}
 
-	if ( $r['show_updated'] ) {
+	if ( $parsed_args['show_updated'] ) {
 		$recently_updated_test = ', IF (DATE_ADD(link_updated, INTERVAL 120 MINUTE) >= NOW(), 1,0) as recently_updated ';
 	} else {
 		$recently_updated_test = '';
 	}
 
-	$get_updated = ( $r['show_updated'] ) ? ', UNIX_TIMESTAMP(link_updated) AS link_updated_f ' : '';
+	$get_updated = ( $parsed_args['show_updated'] ) ? ', UNIX_TIMESTAMP(link_updated) AS link_updated_f ' : '';
 
-	$orderby = strtolower( $r['orderby'] );
+	$orderby = strtolower( $parsed_args['orderby'] );
 	$length  = '';
 	switch ( $orderby ) {
 		case 'length':
@@ -278,13 +278,13 @@
 		$orderby = 'link_name';
 	}
 
-	$order = strtoupper( $r['order'] );
+	$order = strtoupper( $parsed_args['order'] );
 	if ( '' !== $order && ! in_array( $order, array( 'ASC', 'DESC' ) ) ) {
 		$order = 'ASC';
 	}
 
 	$visible = '';
-	if ( $r['hide_invisible'] ) {
+	if ( $parsed_args['hide_invisible'] ) {
 		$visible = "AND link_visible = 'Y'";
 	}
 
@@ -291,8 +291,8 @@
 	$query  = "SELECT * $length $recently_updated_test $get_updated FROM $wpdb->links $join WHERE 1=1 $visible $category_query";
 	$query .= " $exclusions $inclusions $search";
 	$query .= " ORDER BY $orderby $order";
-	if ( $r['limit'] != -1 ) {
-		$query .= ' LIMIT ' . $r['limit'];
+	if ( $parsed_args['limit'] != -1 ) {
+		$query .= ' LIMIT ' . $parsed_args['limit'];
 	}
 
 	$results = $wpdb->get_results( $query );
@@ -303,7 +303,7 @@
 	}
 
 	/** This filter is documented in wp-includes/bookmark.php */
-	return apply_filters( 'get_bookmarks', $results, $r );
+	return apply_filters( 'get_bookmarks', $results, $parsed_args );
 }
 
 /**
@@ -156,9 +156,9 @@
 			 *
 			 * @param array $bookmarks List of the cached bookmarks.
-			 * @param array $r         An array of bookmark query arguments.
+			 * @param array $parsed_args         An array of bookmark query arguments.
 			 */
Index: wp-includes/category-template.php
===================================================================
--- wp-includes/category-template.php	(revision 43719)
+++ wp-includes/category-template.php	(working copy)
@@ -365,14 +365,15 @@
 		$args['taxonomy'] = 'link_category';
 	}
 
-	$r                 = wp_parse_args( $args, $defaults );
-	$option_none_value = $r['option_none_value'];
+	// Parse incoming $args into an array and merge it with $defaults
+	$parsed_args                 = wp_parse_args( $args, $defaults );
+	$option_none_value = $args['option_none_value'];
 
-	if ( ! isset( $r['pad_counts'] ) && $r['show_count'] && $r['hierarchical'] ) {
-		$r['pad_counts'] = true;
+	if ( ! isset( $parsed_args['pad_counts'] ) && $parsed_args['show_count'] && $parsed_args['hierarchical'] ) {
+		$parsed_args['pad_counts'] = true;
 	}
 
-	$tab_index = $r['tab_index'];
+	$tab_index = $parsed_args['tab_index'];
 
 	$tab_index_attribute = '';
 	if ( (int) $tab_index > 0 ) {
@@ -380,21 +381,21 @@
 	}
 
 	// Avoid clashes with the 'name' param of get_terms().
-	$get_terms_args = $r;
+	$get_terms_args = $parsed_args;
 	unset( $get_terms_args['name'] );
-	$categories = get_terms( $r['taxonomy'], $get_terms_args );
+	$categories = get_terms( $parsed_args['taxonomy'], $get_terms_args );
 
-	$name     = esc_attr( $r['name'] );
-	$class    = esc_attr( $r['class'] );
-	$id       = $r['id'] ? esc_attr( $r['id'] ) : $name;
-	$required = $r['required'] ? 'required' : '';
+	$name     = esc_attr( $parsed_args['name'] );
+	$class    = esc_attr( $parsed_args['class'] );
+	$id       = $parsed_args['id'] ? esc_attr( $parsed_args['id'] ) : $name;
+	$required = $parsed_args['required'] ? 'required' : '';
 
-	if ( ! $r['hide_if_empty'] || ! empty( $categories ) ) {
+	if ( ! $parsed_args['hide_if_empty'] || ! empty( $categories ) ) {
 		$output = "<select $required name='$name' id='$id' class='$class' $tab_index_attribute>\n";
 	} else {
 		$output = '';
 	}
-	if ( empty( $categories ) && ! $r['hide_if_empty'] && ! empty( $r['show_option_none'] ) ) {
+	if ( empty( $categories ) && ! $parsed_args['hide_if_empty'] && ! empty( $parsed_args['show_option_none'] ) ) {
 
 		/**
 		 * Filters a taxonomy drop-down display element.
@@ -411,37 +412,37 @@
 		 * @param string       $element  Category name.
 		 * @param WP_Term|null $category The category object, or null if there's no corresponding category.
 		 */
-		$show_option_none = apply_filters( 'list_cats', $r['show_option_none'], null );
+		$show_option_none = apply_filters( 'list_cats', $parsed_args['show_option_none'], null );
 		$output          .= "\t<option value='" . esc_attr( $option_none_value ) . "' selected='selected'>$show_option_none</option>\n";
 	}
 
 	if ( ! empty( $categories ) ) {
 
-		if ( $r['show_option_all'] ) {
+		if ( $parsed_args['show_option_all'] ) {
 
 			/** This filter is documented in wp-includes/category-template.php */
-			$show_option_all = apply_filters( 'list_cats', $r['show_option_all'], null );
-			$selected        = ( '0' === strval( $r['selected'] ) ) ? " selected='selected'" : '';
+			$show_option_all = apply_filters( 'list_cats', $parsed_args['show_option_all'], null );
+			$selected        = ( '0' === strval( $parsed_args['selected'] ) ) ? " selected='selected'" : '';
 			$output         .= "\t<option value='0'$selected>$show_option_all</option>\n";
 		}
 
-		if ( $r['show_option_none'] ) {
+		if ( $parsed_args['show_option_none'] ) {
 
 			/** This filter is documented in wp-includes/category-template.php */
-			$show_option_none = apply_filters( 'list_cats', $r['show_option_none'], null );
-			$selected         = selected( $option_none_value, $r['selected'], false );
+			$show_option_none = apply_filters( 'list_cats', $parsed_args['show_option_none'], null );
+			$selected         = selected( $option_none_value, $parsed_args['selected'], false );
 			$output          .= "\t<option value='" . esc_attr( $option_none_value ) . "'$selected>$show_option_none</option>\n";
 		}
 
-		if ( $r['hierarchical'] ) {
-			$depth = $r['depth'];  // Walk the full depth.
+		if ( $parsed_args['hierarchical'] ) {
+			$depth = $parsed_args['depth'];  // Walk the full depth.
 		} else {
 			$depth = -1; // Flat.
 		}
-		$output .= walk_category_dropdown_tree( $categories, $depth, $r );
+		$output .= walk_category_dropdown_tree( $categories, $depth, $parsed_args );
 	}
 
-	if ( ! $r['hide_if_empty'] || ! empty( $categories ) ) {
+	if ( ! $parsed_args['hide_if_empty'] || ! empty( $categories ) ) {
 		$output .= "</select>\n";
 	}
 	/**
@@ -450,11 +451,11 @@
 	 * @since 2.1.0
 	 *
 	 * @param string $output HTML output.
 	 * @param array  $r      Arguments used to build the drop-down.
 	 */
-	$output = apply_filters( 'wp_dropdown_cats', $output, $r );
+	$output = apply_filters( 'wp_dropdown_cats', $output, $parsed_args );
 
-	if ( $r['echo'] ) {
+	if ( $parsed_args['echo'] ) {
 		echo $output;
 	}
 	return $output;
@@ -537,48 +538,48 @@
 		'use_desc_for_title'  => 1,
 	);
 
-	$r = wp_parse_args( $args, $defaults );
+	$parsed_args = wp_parse_args( $args, $defaults );
 
-	if ( ! isset( $r['pad_counts'] ) && $r['show_count'] && $r['hierarchical'] ) {
-		$r['pad_counts'] = true;
+	if ( ! isset( $parsed_args['pad_counts'] ) && $parsed_args['show_count'] && $parsed_args['hierarchical'] ) {
+		$parsed_args['pad_counts'] = true;
 	}
 
 	// Descendants of exclusions should be excluded too.
-	if ( true == $r['hierarchical'] ) {
+	if ( true == $parsed_args['hierarchical'] ) {
 		$exclude_tree = array();
 
-		if ( $r['exclude_tree'] ) {
-			$exclude_tree = array_merge( $exclude_tree, wp_parse_id_list( $r['exclude_tree'] ) );
+		if ( $parsed_args['exclude_tree'] ) {
+			$exclude_tree = array_merge( $exclude_tree, wp_parse_id_list( $parsed_args['exclude_tree'] ) );
 		}
 
-		if ( $r['exclude'] ) {
-			$exclude_tree = array_merge( $exclude_tree, wp_parse_id_list( $r['exclude'] ) );
+		if ( $parsed_args['exclude'] ) {
+			$exclude_tree = array_merge( $exclude_tree, wp_parse_id_list( $parsed_args['exclude'] ) );
 		}
 
-		$r['exclude_tree'] = $exclude_tree;
-		$r['exclude']      = '';
+		$parsed_args['exclude_tree'] = $exclude_tree;
+		$parsed_args['exclude']      = '';
 	}
 
-	if ( ! isset( $r['class'] ) ) {
-		$r['class'] = ( 'category' == $r['taxonomy'] ) ? 'categories' : $r['taxonomy'];
+	if ( ! isset( $parsed_args['class'] ) ) {
+		$parsed_args['class'] = ( 'category' == $parsed_args['taxonomy'] ) ? 'categories' : $parsed_args['taxonomy'];
 	}
 
-	if ( ! taxonomy_exists( $r['taxonomy'] ) ) {
+	if ( ! taxonomy_exists( $parsed_args['taxonomy'] ) ) {
 		return false;
 	}
 
-	$show_option_all  = $r['show_option_all'];
-	$show_option_none = $r['show_option_none'];
+	$show_option_all  = $parsed_args['show_option_all'];
+	$show_option_none = $parsed_args['show_option_none'];
 
-	$categories = get_categories( $r );
+	$categories = get_categories( $parsed_args );
 
 	$output = '';
-	if ( $r['title_li'] && 'list' == $r['style'] && ( ! empty( $categories ) || ! $r['hide_title_if_empty'] ) ) {
-		$output = '<li class="' . esc_attr( $r['class'] ) . '">' . $r['title_li'] . '<ul>';
+	if ( $parsed_args['title_li'] && 'list' == $parsed_args['style'] && ( ! empty( $categories ) || ! $parsed_args['hide_title_if_empty'] ) ) {
+		$output = '<li class="' . esc_attr( $parsed_args['class'] ) . '">' . $parsed_args['title_li'] . '<ul>';
 	}
 	if ( empty( $categories ) ) {
 		if ( ! empty( $show_option_none ) ) {
-			if ( 'list' == $r['style'] ) {
+			if ( 'list' == $parsed_args['style'] ) {
 				$output .= '<li class="cat-item-none">' . $show_option_none . '</li>';
 			} else {
 				$output .= $show_option_none;
@@ -590,7 +591,7 @@
 			$posts_page = '';
 
 			// For taxonomies that belong only to custom post types, point to a valid archive.
-			$taxonomy_object = get_taxonomy( $r['taxonomy'] );
+			$taxonomy_object = get_taxonomy( $parsed_args['taxonomy'] );
 			if ( ! in_array( 'post', $taxonomy_object->object_type ) && ! in_array( 'page', $taxonomy_object->object_type ) ) {
 				foreach ( $taxonomy_object->object_type as $object_type ) {
 					$_object_type = get_post_type_object( $object_type );
@@ -613,7 +614,7 @@
 			}
 
 			$posts_page = esc_url( $posts_page );
-			if ( 'list' == $r['style'] ) {
+			if ( 'list' == $parsed_args['style'] ) {
 				$output .= "<li class='cat-item-all'><a href='$posts_page'>$show_option_all</a></li>";
 			} else {
 				$output .= "<a href='$posts_page'>$show_option_all</a>";
@@ -620,22 +621,22 @@
 			}
 		}
 
-		if ( empty( $r['current_category'] ) && ( is_category() || is_tax() || is_tag() ) ) {
+		if ( empty( $parsed_args['current_category'] ) && ( is_category() || is_tax() || is_tag() ) ) {
 			$current_term_object = get_queried_object();
-			if ( $current_term_object && $r['taxonomy'] === $current_term_object->taxonomy ) {
-				$r['current_category'] = get_queried_object_id();
+			if ( $current_term_object && $parsed_args['taxonomy'] === $current_term_object->taxonomy ) {
+				$parsed_args['current_category'] = get_queried_object_id();
 			}
 		}
 
-		if ( $r['hierarchical'] ) {
-			$depth = $r['depth'];
+		if ( $parsed_args['hierarchical'] ) {
+			$depth = $parsed_args['depth'];
 		} else {
 			$depth = -1; // Flat.
 		}
-		$output .= walk_category_tree( $categories, $depth, $r );
+		$output .= walk_category_tree( $categories, $depth, $parsed_args );
 	}
 
-	if ( $r['title_li'] && 'list' == $r['style'] && ( ! empty( $categories ) || ! $r['hide_title_if_empty'] ) ) {
+	if ( $parsed_args['title_li'] && 'list' == $parsed_args['style'] && ( ! empty( $categories ) || ! $parsed_args['hide_title_if_empty'] ) ) {
 		$output .= '</ul></li>';
 	}
 
@@ -649,7 +650,7 @@
 	 */
 	$html = apply_filters( 'wp_list_categories', $output, $args );
 
-	if ( $r['echo'] ) {
+	if ( $parsed_args['echo'] ) {
 		echo $html;
 	} else {
 		return $html;
@@ -450,11 +451,11 @@
 	 *
 	 * @param string $output HTML output.
-	 * @param array  $r      Arguments used to build the drop-down.
+	 * @param array  $parsed_args      Arguments used to build the drop-down.
 	 */
Index: wp-includes/class-http.php
===================================================================
--- wp-includes/class-http.php	(revision 43719)
+++ wp-includes/class-http.php	(working copy)
@@ -220,20 +220,20 @@
 			$defaults['redirection'] = 0;
 		}
 
-		$r = wp_parse_args( $args, $defaults );
+		$parsed_args = wp_parse_args( $args, $defaults );
 		/**
 		 * Filters the arguments used in an HTTP request.
 		 *
 		 * @since 2.7.0
 		 *
 		 * @param array  $r   An array of HTTP request arguments.
 		 * @param string $url The request URL.
 		 */
-		$r = apply_filters( 'http_request_args', $r, $url );
+		$parsed_args = apply_filters( 'http_request_args', $parsed_args, $url );
 
 		// The transports decrement this, store a copy of the original value for loop purposes.
-		if ( ! isset( $r['_redirection'] ) ) {
-			$r['_redirection'] = $r['redirection'];
+		if ( ! isset( $parsed_args['_redirection'] ) ) {
+			$parsed_args['_redirection'] = $parsed_args['redirection'];
 		}
 
 		/**
@@ -251,10 +251,10 @@
 		 * @since 2.9.0
 		 *
 		 * @param false|array|WP_Error $preempt Whether to preempt an HTTP request's return value. Default false.
 		 * @param array               $r        HTTP request arguments.
 		 * @param string              $url      The request URL.
 		 */
-		$pre = apply_filters( 'pre_http_request', false, $r, $url );
+		$pre = apply_filters( 'pre_http_request', false, $parsed_args, $url );
 
 		if ( false !== $pre ) {
 			return $pre;
@@ -261,7 +261,7 @@
 		}
 
 		if ( function_exists( 'wp_kses_bad_protocol' ) ) {
-			if ( $r['reject_unsafe_urls'] ) {
+			if ( $parsed_args['reject_unsafe_urls'] ) {
 				$url = wp_http_validate_url( $url );
 			}
 			if ( $url ) {
@@ -281,37 +281,37 @@
 
 		// If we are streaming to a file but no filename was given drop it in the WP temp dir
 		// and pick its name using the basename of the $url
-		if ( $r['stream'] ) {
-			if ( empty( $r['filename'] ) ) {
-				$r['filename'] = get_temp_dir() . basename( $url );
+		if ( $parsed_args['stream'] ) {
+			if ( empty( $parsed_args['filename'] ) ) {
+				$parsed_args['filename'] = get_temp_dir() . basename( $url );
 			}
 
 			// Force some settings if we are streaming to a file and check for existence and perms of destination directory
-			$r['blocking'] = true;
-			if ( ! wp_is_writable( dirname( $r['filename'] ) ) ) {
+			$parsed_args['blocking'] = true;
+			if ( ! wp_is_writable( dirname( $parsed_args['filename'] ) ) ) {
 				return new WP_Error( 'http_request_failed', __( 'Destination directory for file streaming does not exist or is not writable.' ) );
 			}
 		}
 
-		if ( is_null( $r['headers'] ) ) {
-			$r['headers'] = array();
+		if ( is_null( $parsed_args['headers'] ) ) {
+			$parsed_args['headers'] = array();
 		}
 
 		// WP allows passing in headers as a string, weirdly.
-		if ( ! is_array( $r['headers'] ) ) {
-			$processedHeaders = WP_Http::processHeaders( $r['headers'] );
-			$r['headers']     = $processedHeaders['headers'];
+		if ( ! is_array( $parsed_args['headers'] ) ) {
+			$processedHeaders = WP_Http::processHeaders( $parsed_args['headers'] );
+			$parsed_args['headers']     = $processedHeaders['headers'];
 		}
 
 		// Setup arguments
-		$headers = $r['headers'];
-		$data    = $r['body'];
-		$type    = $r['method'];
+		$headers = $parsed_args['headers'];
+		$data    = $parsed_args['body'];
+		$type    = $parsed_args['method'];
 		$options = array(
-			'timeout'   => $r['timeout'],
-			'useragent' => $r['user-agent'],
-			'blocking'  => $r['blocking'],
-			'hooks'     => new WP_HTTP_Requests_Hooks( $url, $r ),
+			'timeout'   => $parsed_args['timeout'],
+			'useragent' => $parsed_args['user-agent'],
+			'blocking'  => $parsed_args['blocking'],
+			'hooks'     => new WP_HTTP_Requests_Hooks( $url, $parsed_args ),
 		);
 
 		// Ensure redirects follow browser behaviour.
@@ -318,35 +318,35 @@
 		$options['hooks']->register( 'requests.before_redirect', array( get_class(), 'browser_redirect_compatibility' ) );
 
 		// Validate redirected URLs.
-		if ( function_exists( 'wp_kses_bad_protocol' ) && $r['reject_unsafe_urls'] ) {
+		if ( function_exists( 'wp_kses_bad_protocol' ) && $parsed_args['reject_unsafe_urls'] ) {
 			$options['hooks']->register( 'requests.before_redirect', array( get_class(), 'validate_redirects' ) );
 		}
 
-		if ( $r['stream'] ) {
-			$options['filename'] = $r['filename'];
+		if ( $parsed_args['stream'] ) {
+			$options['filename'] = $parsed_args['filename'];
 		}
-		if ( empty( $r['redirection'] ) ) {
+		if ( empty( $parsed_args['redirection'] ) ) {
 			$options['follow_redirects'] = false;
 		} else {
-			$options['redirects'] = $r['redirection'];
+			$options['redirects'] = $parsed_args['redirection'];
 		}
 
 		// Use byte limit, if we can
-		if ( isset( $r['limit_response_size'] ) ) {
-			$options['max_bytes'] = $r['limit_response_size'];
+		if ( isset( $parsed_args['limit_response_size'] ) ) {
+			$options['max_bytes'] = $parsed_args['limit_response_size'];
 		}
 
 		// If we've got cookies, use and convert them to Requests_Cookie.
-		if ( ! empty( $r['cookies'] ) ) {
-			$options['cookies'] = WP_Http::normalize_cookies( $r['cookies'] );
+		if ( ! empty( $parsed_args['cookies'] ) ) {
+			$options['cookies'] = WP_Http::normalize_cookies( $parsed_args['cookies'] );
 		}
 
 		// SSL certificate handling
-		if ( ! $r['sslverify'] ) {
+		if ( ! $parsed_args['sslverify'] ) {
 			$options['verify']     = false;
 			$options['verifyname'] = false;
 		} else {
-			$options['verify'] = $r['sslcertificates'];
+			$options['verify'] = $parsed_args['sslcertificates'];
 		}
 
 		// All non-GET/HEAD requests should put the arguments in the form body.
@@ -384,7 +384,7 @@
 			$requests_response = Requests::request( $url, $headers, $data, $type, $options );
 
 			// Convert the response into an array
-			$http_response = new WP_HTTP_Requests_Response( $requests_response, $r['filename'] );
+			$http_response = new WP_HTTP_Requests_Response( $requests_response, $parsed_args['filename'] );
 			$response      = $http_response->to_array();
 
 			// Add the original object to the array.
@@ -403,15 +403,15 @@
 		 * @param array|WP_Error $response HTTP response or WP_Error object.
 		 * @param string         $context  Context under which the hook is fired.
 		 * @param string         $class    HTTP transport used.
 		 * @param array          $r        HTTP request arguments.
 		 * @param string         $url      The request URL.
 		 */
-		do_action( 'http_api_debug', $response, 'response', 'Requests', $r, $url );
+		do_action( 'http_api_debug', $response, 'response', 'Requests', $parsed_args, $url );
 		if ( is_wp_error( $response ) ) {
 			return $response;
 		}
 
-		if ( ! $r['blocking'] ) {
+		if ( ! $parsed_args['blocking'] ) {
 			return array(
 				'headers'       => array(),
 				'body'          => '',
@@ -430,10 +430,10 @@
 		 * @since 2.9.0
 		 *
 		 * @param array  $response HTTP response.
 		 * @param array  $r        HTTP request arguments.
 		 * @param string $url      The request URL.
 		 */
-		return apply_filters( 'http_response', $response, $r, $url );
+		return apply_filters( 'http_response', $response, $parsed_args, $url );
 	}
 
 	/**
@@ -592,8 +592,8 @@
 	 */
 	public function post( $url, $args = array() ) {
 		$defaults = array( 'method' => 'POST' );
-		$r        = wp_parse_args( $args, $defaults );
-		return $this->request( $url, $r );
+		$parsed_args        = wp_parse_args( $args, $defaults );
+		return $this->request( $url, $parsed_args );
 	}
 
 	/**
@@ -609,8 +609,8 @@
 	 */
 	public function get( $url, $args = array() ) {
 		$defaults = array( 'method' => 'GET' );
-		$r        = wp_parse_args( $args, $defaults );
-		return $this->request( $url, $r );
+		$parsed_args        = wp_parse_args( $args, $defaults );
+		return $this->request( $url, $parsed_args );
 	}
 
 	/**
@@ -626,8 +626,8 @@
 	 */
 	public function head( $url, $args = array() ) {
 		$defaults = array( 'method' => 'HEAD' );
-		$r        = wp_parse_args( $args, $defaults );
-		return $this->request( $url, $r );
+		$parsed_args        = wp_parse_args( $args, $defaults );
+		return $this->request( $url, $parsed_args );
 	}
 
 	/**
@@ -220,20 +220,20 @@
 		 * @since 2.7.0
 		 *
-		 * @param array  $r   An array of HTTP request arguments.
+		 * @param array  $parsed_args   An array of HTTP request arguments.
 		 * @param string $url The request URL.
 		 */
@@ -251,10 +251,10 @@
 		 *
 		 * @param false|array|WP_Error $preempt Whether to preempt an HTTP request's return value. Default false.
-		 * @param array               $r        HTTP request arguments.
+		 * @param array               $parsed_args        HTTP request arguments.
 		 * @param string              $url      The request URL.
 		 */
@@ -403,15 +403,15 @@
 		 * @param string         $context  Context under which the hook is fired.
 		 * @param string         $class    HTTP transport used.
-		 * @param array          $r        HTTP request arguments.
+		 * @param array          $parsed_args        HTTP request arguments.
 		 * @param string         $url      The request URL.
 		 */
@@ -430,10 +430,10 @@
 		 *
 		 * @param array  $response HTTP response.
-		 * @param array  $r        HTTP request arguments.
+		 * @param array  $parsed_args        HTTP request arguments.
 		 * @param string $url      The request URL.
 		 */
Index: wp-includes/class-wp-http-curl.php
===================================================================
--- wp-includes/class-wp-http-curl.php	(revision 43719)
+++ wp-includes/class-wp-http-curl.php	(working copy)
@@ -79,18 +79,18 @@
 			'cookies'     => array(),
 		);
 
-		$r = wp_parse_args( $args, $defaults );
+		$parsed_args = wp_parse_args( $args, $defaults );
 
-		if ( isset( $r['headers']['User-Agent'] ) ) {
-			$r['user-agent'] = $r['headers']['User-Agent'];
-			unset( $r['headers']['User-Agent'] );
-		} elseif ( isset( $r['headers']['user-agent'] ) ) {
-			$r['user-agent'] = $r['headers']['user-agent'];
-			unset( $r['headers']['user-agent'] );
+		if ( isset( $parsed_args['headers']['User-Agent'] ) ) {
+			$parsed_args['user-agent'] = $parsed_args['headers']['User-Agent'];
+			unset( $parsed_args['headers']['User-Agent'] );
+		} elseif ( isset( $parsed_args['headers']['user-agent'] ) ) {
+			$parsed_args['user-agent'] = $parsed_args['headers']['user-agent'];
+			unset( $parsed_args['headers']['user-agent'] );
 		}
 
 		// Construct Cookie: header if any cookies are set.
-		WP_Http::buildCookieHeader( $r );
+		WP_Http::buildCookieHeader( $parsed_args );
 
 		$handle = curl_init();
 
@@ -109,8 +109,8 @@
 			}
 		}
 
-		$is_local   = isset( $r['local'] ) && $r['local'];
-		$ssl_verify = isset( $r['sslverify'] ) && $r['sslverify'];
+		$is_local   = isset( $parsed_args['local'] ) && $parsed_args['local'];
+		$ssl_verify = isset( $parsed_args['sslverify'] ) && $parsed_args['sslverify'];
 		if ( $is_local ) {
 			/** This filter is documented in wp-includes/class-wp-http-streams.php */
 			$ssl_verify = apply_filters( 'https_local_ssl_verify', $ssl_verify, $url );
@@ -123,7 +123,7 @@
 		 * CURLOPT_TIMEOUT and CURLOPT_CONNECTTIMEOUT expect integers. Have to use ceil since.
 		 * a value of 0 will allow an unlimited timeout.
 		 */
-		$timeout = (int) ceil( $r['timeout'] );
+		$timeout = (int) ceil( $parsed_args['timeout'] );
 		curl_setopt( $handle, CURLOPT_CONNECTTIMEOUT, $timeout );
 		curl_setopt( $handle, CURLOPT_TIMEOUT, $timeout );
 
@@ -133,10 +133,10 @@
 		curl_setopt( $handle, CURLOPT_SSL_VERIFYPEER, $ssl_verify );
 
 		if ( $ssl_verify ) {
-			curl_setopt( $handle, CURLOPT_CAINFO, $r['sslcertificates'] );
+			curl_setopt( $handle, CURLOPT_CAINFO, $parsed_args['sslcertificates'] );
 		}
 
-		curl_setopt( $handle, CURLOPT_USERAGENT, $r['user-agent'] );
+		curl_setopt( $handle, CURLOPT_USERAGENT, $parsed_args['user-agent'] );
 
 		/*
 		 * The option doesn't work with safe mode or when open_basedir is set, and there's
@@ -147,27 +147,27 @@
 			curl_setopt( $handle, CURLOPT_PROTOCOLS, CURLPROTO_HTTP | CURLPROTO_HTTPS );
 		}
 
-		switch ( $r['method'] ) {
+		switch ( $parsed_args['method'] ) {
 			case 'HEAD':
 				curl_setopt( $handle, CURLOPT_NOBODY, true );
 				break;
 			case 'POST':
 				curl_setopt( $handle, CURLOPT_POST, true );
-				curl_setopt( $handle, CURLOPT_POSTFIELDS, $r['body'] );
+				curl_setopt( $handle, CURLOPT_POSTFIELDS, $parsed_args['body'] );
 				break;
 			case 'PUT':
 				curl_setopt( $handle, CURLOPT_CUSTOMREQUEST, 'PUT' );
-				curl_setopt( $handle, CURLOPT_POSTFIELDS, $r['body'] );
+				curl_setopt( $handle, CURLOPT_POSTFIELDS, $parsed_args['body'] );
 				break;
 			default:
-				curl_setopt( $handle, CURLOPT_CUSTOMREQUEST, $r['method'] );
-				if ( ! is_null( $r['body'] ) ) {
-					curl_setopt( $handle, CURLOPT_POSTFIELDS, $r['body'] );
+				curl_setopt( $handle, CURLOPT_CUSTOMREQUEST, $parsed_args['method'] );
+				if ( ! is_null( $parsed_args['body'] ) ) {
+					curl_setopt( $handle, CURLOPT_POSTFIELDS, $parsed_args['body'] );
 				}
 				break;
 		}
 
-		if ( true === $r['blocking'] ) {
+		if ( true === $parsed_args['blocking'] ) {
 			curl_setopt( $handle, CURLOPT_HEADERFUNCTION, array( $this, 'stream_headers' ) );
 			curl_setopt( $handle, CURLOPT_WRITEFUNCTION, array( $this, 'stream_body' ) );
 		}
@@ -174,18 +174,18 @@
 
 		curl_setopt( $handle, CURLOPT_HEADER, false );
 
-		if ( isset( $r['limit_response_size'] ) ) {
-			$this->max_body_length = intval( $r['limit_response_size'] );
+		if ( isset( $parsed_args['limit_response_size'] ) ) {
+			$this->max_body_length = intval( $parsed_args['limit_response_size'] );
 		} else {
 			$this->max_body_length = false;
 		}
 
 		// If streaming to a file open a file handle, and setup our curl streaming handler.
-		if ( $r['stream'] ) {
+		if ( $parsed_args['stream'] ) {
 			if ( ! WP_DEBUG ) {
-				$this->stream_handle = @fopen( $r['filename'], 'w+' );
+				$this->stream_handle = @fopen( $parsed_args['filename'], 'w+' );
 			} else {
-				$this->stream_handle = fopen( $r['filename'], 'w+' );
+				$this->stream_handle = fopen( $parsed_args['filename'], 'w+' );
 			}
 			if ( ! $this->stream_handle ) {
 				return new WP_Error(
@@ -194,7 +194,7 @@
 						/* translators: 1: fopen(), 2: file name */
 						__( 'Could not open handle for %1$s to %2$s.' ),
 						'fopen()',
-						$r['filename']
+						$parsed_args['filename']
 					)
 				);
 			}
@@ -202,16 +202,16 @@
 			$this->stream_handle = false;
 		}
 
-		if ( ! empty( $r['headers'] ) ) {
+		if ( ! empty( $parsed_args['headers'] ) ) {
 			// cURL expects full header strings in each element.
 			$headers = array();
-			foreach ( $r['headers'] as $name => $value ) {
+			foreach ( $parsed_args['headers'] as $name => $value ) {
 				$headers[] = "{$name}: $value";
 			}
 			curl_setopt( $handle, CURLOPT_HTTPHEADER, $headers );
 		}
 
-		if ( $r['httpversion'] == '1.0' ) {
+		if ( $parsed_args['httpversion'] == '1.0' ) {
 			curl_setopt( $handle, CURLOPT_HTTP_VERSION, CURL_HTTP_VERSION_1_0 );
 		} else {
 			curl_setopt( $handle, CURLOPT_HTTP_VERSION, CURL_HTTP_VERSION_1_1 );
@@ -226,13 +226,13 @@
 		 * @since 2.8.0
 		 *
 		 * @param resource $handle  The cURL handle returned by curl_init() (passed by reference).
 		 * @param array    $r       The HTTP request arguments.
 		 * @param string   $url     The request URL.
 		 */
-		do_action_ref_array( 'http_api_curl', array( &$handle, $r, $url ) );
+		do_action_ref_array( 'http_api_curl', array( &$handle, $parsed_args, $url ) );
 
 		// We don't need to return the body, so don't. Just execute request and return.
-		if ( ! $r['blocking'] ) {
+		if ( ! $parsed_args['blocking'] ) {
 			curl_exec( $handle );
 
 			if ( $curl_error = curl_error( $handle ) ) {
@@ -271,7 +271,7 @@
 		if ( $curl_error || ( 0 == strlen( $theBody ) && empty( $theHeaders['headers'] ) ) ) {
 			if ( CURLE_WRITE_ERROR /* 23 */ == $curl_error ) {
 				if ( ! $this->max_body_length || $this->max_body_length != $bytes_written_total ) {
-					if ( $r['stream'] ) {
+					if ( $parsed_args['stream'] ) {
 						curl_close( $handle );
 						fclose( $this->stream_handle );
 						return new WP_Error( 'http_request_failed', __( 'Failed to write request to temporary file.' ) );
@@ -294,7 +294,7 @@
 
 		curl_close( $handle );
 
-		if ( $r['stream'] ) {
+		if ( $parsed_args['stream'] ) {
 			fclose( $this->stream_handle );
 		}
 
@@ -303,15 +303,15 @@
 			'body'     => null,
 			'response' => $theHeaders['response'],
 			'cookies'  => $theHeaders['cookies'],
-			'filename' => $r['filename'],
+			'filename' => $parsed_args['filename'],
 		);
 
 		// Handle redirects.
-		if ( false !== ( $redirect_response = WP_HTTP::handle_redirects( $url, $r, $response ) ) ) {
+		if ( false !== ( $redirect_response = WP_HTTP::handle_redirects( $url, $parsed_args, $response ) ) ) {
 			return $redirect_response;
 		}
 
-		if ( true === $r['decompress'] && true === WP_Http_Encoding::should_decode( $theHeaders['headers'] ) ) {
+		if ( true === $parsed_args['decompress'] && true === WP_Http_Encoding::should_decode( $theHeaders['headers'] ) ) {
 			$theBody = WP_Http_Encoding::decompress( $theBody );
 		}
 
@@ -226,13 +226,13 @@
 		 *
 		 * @param resource $handle  The cURL handle returned by curl_init() (passed by reference).
-		 * @param array    $r       The HTTP request arguments.
+		 * @param array    $parsed_args       The HTTP request arguments.
 		 * @param string   $url     The request URL.
 		 */
Index: wp-includes/comment-template.php
===================================================================
--- wp-includes/comment-template.php	(revision 43719)
+++ wp-includes/comment-template.php	(working copy)
@@ -2007,7 +2007,7 @@
 		'echo'              => true,
 	);
 
-	$r = wp_parse_args( $args, $defaults );
+	$parsed_args = wp_parse_args( $args, $defaults );
 
 	/**
 	 * Filters the arguments used in retrieving the comment list.
@@ -2016,9 +2016,9 @@
 	 *
 	 * @see wp_list_comments()
 	 *
 	 * @param array $r An array of arguments for displaying comments.
 	 */
-	$r = apply_filters( 'wp_list_comments_args', $r );
+	$parsed_args = apply_filters( 'wp_list_comments_args', $parsed_args );
 
 	// Figure out what comments we'll be looping through ($_comments)
 	if ( null !== $comments ) {
@@ -2026,12 +2026,12 @@
 		if ( empty( $comments ) ) {
 			return;
 		}
-		if ( 'all' != $r['type'] ) {
+		if ( 'all' != $parsed_args['type'] ) {
 			$comments_by_type = separate_comments( $comments );
-			if ( empty( $comments_by_type[ $r['type'] ] ) ) {
+			if ( empty( $comments_by_type[ $parsed_args['type'] ] ) ) {
 				return;
 			}
-			$_comments = $comments_by_type[ $r['type'] ];
+			$_comments = $comments_by_type[ $parsed_args['type'] ];
 		} else {
 			$_comments = $comments;
 		}
@@ -2040,7 +2040,7 @@
 		 * If 'page' or 'per_page' has been passed, and does not match what's in $wp_query,
 		 * perform a separate comment query and allow Walker_Comment to paginate.
 		 */
-		if ( $r['page'] || $r['per_page'] ) {
+		if ( $parsed_args['page'] || $parsed_args['per_page'] ) {
 			$current_cpage = get_query_var( 'cpage' );
 			if ( ! $current_cpage ) {
 				$current_cpage = 'newest' === get_option( 'default_comments_page' ) ? 1 : $wp_query->max_num_comment_pages;
@@ -2047,7 +2047,7 @@
 			}
 
 			$current_per_page = get_query_var( 'comments_per_page' );
-			if ( $r['page'] != $current_cpage || $r['per_page'] != $current_per_page ) {
+			if ( $parsed_args['page'] != $current_cpage || $parsed_args['per_page'] != $current_per_page ) {
 				$comment_args = array(
 					'post_id' => get_the_ID(),
 					'orderby' => 'comment_date_gmt',
@@ -2066,13 +2066,13 @@
 
 				$comments = get_comments( $comment_args );
 
-				if ( 'all' != $r['type'] ) {
+				if ( 'all' != $parsed_args['type'] ) {
 					$comments_by_type = separate_comments( $comments );
-					if ( empty( $comments_by_type[ $r['type'] ] ) ) {
+					if ( empty( $comments_by_type[ $parsed_args['type'] ] ) ) {
 						return;
 					}
 
-					$_comments = $comments_by_type[ $r['type'] ];
+					$_comments = $comments_by_type[ $parsed_args['type'] ];
 				} else {
 					$_comments = $comments;
 				}
@@ -2083,14 +2083,14 @@
 			if ( empty( $wp_query->comments ) ) {
 				return;
 			}
-			if ( 'all' != $r['type'] ) {
+			if ( 'all' != $parsed_args['type'] ) {
 				if ( empty( $wp_query->comments_by_type ) ) {
 					$wp_query->comments_by_type = separate_comments( $wp_query->comments );
 				}
-				if ( empty( $wp_query->comments_by_type[ $r['type'] ] ) ) {
+				if ( empty( $wp_query->comments_by_type[ $parsed_args['type'] ] ) ) {
 					return;
 				}
-				$_comments = $wp_query->comments_by_type[ $r['type'] ];
+				$_comments = $wp_query->comments_by_type[ $parsed_args['type'] ];
 			} else {
 				$_comments = $wp_query->comments;
 			}
@@ -2099,7 +2099,7 @@
 				$default_comments_page = get_option( 'default_comments_page' );
 				$cpage                 = get_query_var( 'cpage' );
 				if ( 'newest' === $default_comments_page ) {
-					$r['cpage'] = $cpage;
+					$parsed_args['cpage'] = $cpage;
 
 					/*
 					* When first page shows oldest comments, post permalink is the same as
@@ -2106,66 +2106,66 @@
 					* the comment permalink.
 					*/
 				} elseif ( $cpage == 1 ) {
-					$r['cpage'] = '';
+					$parsed_args['cpage'] = '';
 				} else {
-					$r['cpage'] = $cpage;
+					$parsed_args['cpage'] = $cpage;
 				}
 
-				$r['page']     = 0;
-				$r['per_page'] = 0;
+				$parsed_args['page']     = 0;
+				$parsed_args['per_page'] = 0;
 			}
 		}
 	}
 
-	if ( '' === $r['per_page'] && get_option( 'page_comments' ) ) {
-		$r['per_page'] = get_query_var( 'comments_per_page' );
+	if ( '' === $parsed_args['per_page'] && get_option( 'page_comments' ) ) {
+		$parsed_args['per_page'] = get_query_var( 'comments_per_page' );
 	}
 
-	if ( empty( $r['per_page'] ) ) {
-		$r['per_page'] = 0;
-		$r['page']     = 0;
+	if ( empty( $parsed_args['per_page'] ) ) {
+		$parsed_args['per_page'] = 0;
+		$parsed_args['page']     = 0;
 	}
 
-	if ( '' === $r['max_depth'] ) {
+	if ( '' === $parsed_args['max_depth'] ) {
 		if ( get_option( 'thread_comments' ) ) {
-			$r['max_depth'] = get_option( 'thread_comments_depth' );
+			$parsed_args['max_depth'] = get_option( 'thread_comments_depth' );
 		} else {
-			$r['max_depth'] = -1;
+			$parsed_args['max_depth'] = -1;
 		}
 	}
 
-	if ( '' === $r['page'] ) {
+	if ( '' === $parsed_args['page'] ) {
 		if ( empty( $overridden_cpage ) ) {
-			$r['page'] = get_query_var( 'cpage' );
+			$parsed_args['page'] = get_query_var( 'cpage' );
 		} else {
-			$threaded  = ( -1 != $r['max_depth'] );
-			$r['page'] = ( 'newest' == get_option( 'default_comments_page' ) ) ? get_comment_pages_count( $_comments, $r['per_page'], $threaded ) : 1;
-			set_query_var( 'cpage', $r['page'] );
+			$threaded  = ( -1 != $parsed_args['max_depth'] );
+			$parsed_args['page'] = ( 'newest' == get_option( 'default_comments_page' ) ) ? get_comment_pages_count( $_comments, $r['per_page'], $threaded ) : 1;
+			set_query_var( 'cpage', $parsed_args['page'] );
 		}
 	}
 	// Validation check
-	$r['page'] = intval( $r['page'] );
-	if ( 0 == $r['page'] && 0 != $r['per_page'] ) {
-		$r['page'] = 1;
+	$parsed_args['page'] = intval( $parsed_args['page'] );
+	if ( 0 == $parsed_args['page'] && 0 != $parsed_args['per_page'] ) {
+		$parsed_args['page'] = 1;
 	}
 
-	if ( null === $r['reverse_top_level'] ) {
-		$r['reverse_top_level'] = ( 'desc' == get_option( 'comment_order' ) );
+	if ( null === $parsed_args['reverse_top_level'] ) {
+		$parsed_args['reverse_top_level'] = ( 'desc' == get_option( 'comment_order' ) );
 	}
 
 	wp_queue_comments_for_comment_meta_lazyload( $_comments );
 
-	if ( empty( $r['walker'] ) ) {
+	if ( empty( $parsed_args['walker'] ) ) {
 		$walker = new Walker_Comment;
 	} else {
-		$walker = $r['walker'];
+		$walker = $parsed_args['walker'];
 	}
 
-	$output = $walker->paged_walk( $_comments, $r['max_depth'], $r['page'], $r['per_page'], $r );
+	$output = $walker->paged_walk( $_comments, $parsed_args['max_depth'], $parsed_args['page'], $parsed_args['per_page'], $parsed_args );
 
 	$in_comment_loop = false;
 
-	if ( $r['echo'] ) {
+	if ( $parsed_args['echo'] ) {
 		echo $output;
 	} else {
 		return $output;
@@ -2016,9 +2016,9 @@
 	 * @see wp_list_comments()
 	 *
-	 * @param array $r An array of arguments for displaying comments.
+	 * @param array $parsed_args An array of arguments for displaying comments.
 	 */
Index: wp-includes/general-template.php
===================================================================
--- wp-includes/general-template.php	(revision 43719)
+++ wp-includes/general-template.php	(working copy)
@@ -1746,24 +1746,24 @@
 		'post_type'       => 'post',
 	);
 
-	$r = wp_parse_args( $args, $defaults );
+	$parsed_args = wp_parse_args( $args, $defaults );
 
-	$post_type_object = get_post_type_object( $r['post_type'] );
+	$post_type_object = get_post_type_object( $parsed_args['post_type'] );
 	if ( ! is_post_type_viewable( $post_type_object ) ) {
 		return;
 	}
-	$r['post_type'] = $post_type_object->name;
+	$parsed_args['post_type'] = $post_type_object->name;
 
-	if ( '' == $r['type'] ) {
-		$r['type'] = 'monthly';
+	if ( '' == $parsed_args['type'] ) {
+		$parsed_args['type'] = 'monthly';
 	}
 
-	if ( ! empty( $r['limit'] ) ) {
-		$r['limit'] = absint( $r['limit'] );
-		$r['limit'] = ' LIMIT ' . $r['limit'];
+	if ( ! empty( $parsed_args['limit'] ) ) {
+		$parsed_args['limit'] = absint( $parsed_args['limit'] );
+		$parsed_args['limit'] = ' LIMIT ' . $parsed_args['limit'];
 	}
 
-	$order = strtoupper( $r['order'] );
+	$order = strtoupper( $parsed_args['order'] );
 	if ( $order !== 'ASC' ) {
 		$order = 'DESC';
 	}
@@ -1771,7 +1771,7 @@
 	// this is what will separate dates on weekly archive links
 	$archive_week_separator = '&#8211;';
 
-	$sql_where = $wpdb->prepare( "WHERE post_type = %s AND post_status = 'publish'", $r['post_type'] );
+	$sql_where = $wpdb->prepare( "WHERE post_type = %s AND post_status = 'publish'", $parsed_args['post_type'] );
 
 	/**
 	 * Filters the SQL WHERE clause for retrieving archives.
@@ -1779,9 +1779,9 @@
 	 * @since 2.2.0
 	 *
 	 * @param string $sql_where Portion of SQL query containing the WHERE clause.
 	 * @param array  $r         An array of default arguments.
 	 */
-	$where = apply_filters( 'getarchives_where', $sql_where, $r );
+	$where = apply_filters( 'getarchives_where', $sql_where, $parsed_args );
 
 	/**
 	 * Filters the SQL JOIN clause for retrieving archives.
@@ -1789,17 +1789,17 @@
 	 * @since 2.2.0
 	 *
 	 * @param string $sql_join Portion of SQL query containing JOIN clause.
 	 * @param array  $r        An array of default arguments.
 	 */
-	$join = apply_filters( 'getarchives_join', '', $r );
+	$join = apply_filters( 'getarchives_join', '', $parsed_args );
 
 	$output = '';
 
 	$last_changed = wp_cache_get_last_changed( 'posts' );
 
-	$limit = $r['limit'];
+	$limit = $parsed_args['limit'];
 
-	if ( 'monthly' == $r['type'] ) {
+	if ( 'monthly' == $parsed_args['type'] ) {
 		$query = "SELECT YEAR(post_date) AS `year`, MONTH(post_date) AS `month`, count(ID) as posts FROM $wpdb->posts $join $where GROUP BY YEAR(post_date), MONTH(post_date) ORDER BY post_date $order $limit";
 		$key   = md5( $query );
 		$key   = "wp_get_archives:$key:$last_changed";
@@ -1808,21 +1808,21 @@
 			wp_cache_set( $key, $results, 'posts' );
 		}
 		if ( $results ) {
-			$after = $r['after'];
+			$after = $parsed_args['after'];
 			foreach ( (array) $results as $result ) {
 				$url = get_month_link( $result->year, $result->month );
-				if ( 'post' !== $r['post_type'] ) {
-					$url = add_query_arg( 'post_type', $r['post_type'], $url );
+				if ( 'post' !== $parsed_args['post_type'] ) {
+					$url = add_query_arg( 'post_type', $parsed_args['post_type'], $url );
 				}
 				/* translators: 1: month name, 2: 4-digit year */
 				$text = sprintf( __( '%1$s %2$d' ), $wp_locale->get_month( $result->month ), $result->year );
-				if ( $r['show_post_count'] ) {
-					$r['after'] = '&nbsp;(' . $result->posts . ')' . $after;
+				if ( $parsed_args['show_post_count'] ) {
+					$parsed_args['after'] = '&nbsp;(' . $result->posts . ')' . $after;
 				}
-				$output .= get_archives_link( $url, $text, $r['format'], $r['before'], $r['after'] );
+				$output .= get_archives_link( $url, $text, $parsed_args['format'], $parsed_args['before'], $parsed_args['after'] );
 			}
 		}
-	} elseif ( 'yearly' == $r['type'] ) {
+	} elseif ( 'yearly' == $parsed_args['type'] ) {
 		$query = "SELECT YEAR(post_date) AS `year`, count(ID) as posts FROM $wpdb->posts $join $where GROUP BY YEAR(post_date) ORDER BY post_date $order $limit";
 		$key   = md5( $query );
 		$key   = "wp_get_archives:$key:$last_changed";
@@ -1831,20 +1831,20 @@
 			wp_cache_set( $key, $results, 'posts' );
 		}
 		if ( $results ) {
-			$after = $r['after'];
+			$after = $parsed_args['after'];
 			foreach ( (array) $results as $result ) {
 				$url = get_year_link( $result->year );
-				if ( 'post' !== $r['post_type'] ) {
-					$url = add_query_arg( 'post_type', $r['post_type'], $url );
+				if ( 'post' !== $parsed_args['post_type'] ) {
+					$url = add_query_arg( 'post_type', $parsed_args['post_type'], $url );
 				}
 				$text = sprintf( '%d', $result->year );
-				if ( $r['show_post_count'] ) {
-					$r['after'] = '&nbsp;(' . $result->posts . ')' . $after;
+				if ( $parsed_args['show_post_count'] ) {
+					$parsed_args['after'] = '&nbsp;(' . $result->posts . ')' . $after;
 				}
-				$output .= get_archives_link( $url, $text, $r['format'], $r['before'], $r['after'] );
+				$output .= get_archives_link( $url, $text, $parsed_args['format'], $parsed_args['before'], $parsed_args['after'] );
 			}
 		}
-	} elseif ( 'daily' == $r['type'] ) {
+	} elseif ( 'daily' == $parsed_args['type'] ) {
 		$query = "SELECT YEAR(post_date) AS `year`, MONTH(post_date) AS `month`, DAYOFMONTH(post_date) AS `dayofmonth`, count(ID) as posts FROM $wpdb->posts $join $where GROUP BY YEAR(post_date), MONTH(post_date), DAYOFMONTH(post_date) ORDER BY post_date $order $limit";
 		$key   = md5( $query );
 		$key   = "wp_get_archives:$key:$last_changed";
@@ -1853,21 +1853,21 @@
 			wp_cache_set( $key, $results, 'posts' );
 		}
 		if ( $results ) {
-			$after = $r['after'];
+			$after = $parsed_args['after'];
 			foreach ( (array) $results as $result ) {
 				$url = get_day_link( $result->year, $result->month, $result->dayofmonth );
-				if ( 'post' !== $r['post_type'] ) {
-					$url = add_query_arg( 'post_type', $r['post_type'], $url );
+				if ( 'post' !== $parsed_args['post_type'] ) {
+					$url = add_query_arg( 'post_type', $parsed_args['post_type'], $url );
 				}
 				$date = sprintf( '%1$d-%2$02d-%3$02d 00:00:00', $result->year, $result->month, $result->dayofmonth );
 				$text = mysql2date( get_option( 'date_format' ), $date );
-				if ( $r['show_post_count'] ) {
-					$r['after'] = '&nbsp;(' . $result->posts . ')' . $after;
+				if ( $parsed_args['show_post_count'] ) {
+					$parsed_args['after'] = '&nbsp;(' . $result->posts . ')' . $after;
 				}
-				$output .= get_archives_link( $url, $text, $r['format'], $r['before'], $r['after'] );
+				$output .= get_archives_link( $url, $text, $parsed_args['format'], $parsed_args['before'], $parsed_args['after'] );
 			}
 		}
-	} elseif ( 'weekly' == $r['type'] ) {
+	} elseif ( 'weekly' == $parsed_args['type'] ) {
 		$week  = _wp_mysql_week( '`post_date`' );
 		$query = "SELECT DISTINCT $week AS `week`, YEAR( `post_date` ) AS `yr`, DATE_FORMAT( `post_date`, '%Y-%m-%d' ) AS `yyyymmdd`, count( `ID` ) AS `posts` FROM `$wpdb->posts` $join $where GROUP BY $week, YEAR( `post_date` ) ORDER BY `post_date` $order $limit";
 		$key   = md5( $query );
@@ -1878,7 +1878,7 @@
 		}
 		$arc_w_last = '';
 		if ( $results ) {
-			$after = $r['after'];
+			$after = $parsed_args['after'];
 			foreach ( (array) $results as $result ) {
 				if ( $result->week != $arc_w_last ) {
 					$arc_year       = $result->yr;
@@ -1893,19 +1893,19 @@
 						),
 						home_url( '/' )
 					);
-					if ( 'post' !== $r['post_type'] ) {
-						$url = add_query_arg( 'post_type', $r['post_type'], $url );
+					if ( 'post' !== $parsed_args['post_type'] ) {
+						$url = add_query_arg( 'post_type', $parsed_args['post_type'], $url );
 					}
 					$text = $arc_week_start . $archive_week_separator . $arc_week_end;
-					if ( $r['show_post_count'] ) {
-						$r['after'] = '&nbsp;(' . $result->posts . ')' . $after;
+					if ( $parsed_args['show_post_count'] ) {
+						$parsed_args['after'] = '&nbsp;(' . $result->posts . ')' . $after;
 					}
-					$output .= get_archives_link( $url, $text, $r['format'], $r['before'], $r['after'] );
+					$output .= get_archives_link( $url, $text, $parsed_args['format'], $parsed_args['before'], $parsed_args['after'] );
 				}
 			}
 		}
-	} elseif ( ( 'postbypost' == $r['type'] ) || ( 'alpha' == $r['type'] ) ) {
-		$orderby = ( 'alpha' == $r['type'] ) ? 'post_title ASC ' : 'post_date DESC, ID DESC ';
+	} elseif ( ( 'postbypost' == $parsed_args['type'] ) || ( 'alpha' == $parsed_args['type'] ) ) {
+		$orderby = ( 'alpha' == $parsed_args['type'] ) ? 'post_title ASC ' : 'post_date DESC, ID DESC ';
 		$query   = "SELECT * FROM $wpdb->posts $join $where ORDER BY $orderby $limit";
 		$key     = md5( $query );
 		$key     = "wp_get_archives:$key:$last_changed";
@@ -1923,12 +1923,12 @@
 					} else {
 						$text = $result->ID;
 					}
-					$output .= get_archives_link( $url, $text, $r['format'], $r['before'], $r['after'] );
+					$output .= get_archives_link( $url, $text, $parsed_args['format'], $parsed_args['before'], $parsed_args['after'] );
 				}
 			}
 		}
 	}
-	if ( $r['echo'] ) {
+	if ( $parsed_args['echo'] ) {
 		echo $output;
 	} else {
 		return $output;
@@ -1779,9 +1779,9 @@
 	 *
 	 * @param string $sql_where Portion of SQL query containing the WHERE clause.
-	 * @param array  $r         An array of default arguments.
+	 * @param array  $parsed_args         An array of default arguments.
 	 */
@@ -1789,17 +1789,17 @@
 	 *
 	 * @param string $sql_join Portion of SQL query containing JOIN clause.
-	 * @param array  $r        An array of default arguments.
+	 * @param array  $parsed_args        An array of default arguments.
 	 */
Index: wp-includes/post.php
===================================================================
--- wp-includes/post.php	(revision 43719)
+++ wp-includes/post.php	(working copy)
@@ -550,15 +550,15 @@
 		'post_parent' => 0,
 	);
 
-	$r = wp_parse_args( $args, $defaults );
+	$parsed_args = wp_parse_args( $args, $defaults );
 
-	$children = get_posts( $r );
+	$children = get_posts( $parsed_args );
 
 	if ( ! $children ) {
 		return $kids;
 	}
 
-	if ( ! empty( $r['fields'] ) ) {
+	if ( ! empty( $parsed_args['fields'] ) ) {
 		return $children;
 	}
 
@@ -1860,29 +1860,29 @@
 		'suppress_filters' => true,
 	);
 
-	$r = wp_parse_args( $args, $defaults );
-	if ( empty( $r['post_status'] ) ) {
-		$r['post_status'] = ( 'attachment' == $r['post_type'] ) ? 'inherit' : 'publish';
+	$parsed_args = wp_parse_args( $args, $defaults );
+	if ( empty( $parsed_args['post_status'] ) ) {
+		$parsed_args['post_status'] = ( 'attachment' == $parsed_args['post_type'] ) ? 'inherit' : 'publish';
 	}
-	if ( ! empty( $r['numberposts'] ) && empty( $r['posts_per_page'] ) ) {
-		$r['posts_per_page'] = $r['numberposts'];
+	if ( ! empty( $parsed_args['numberposts'] ) && empty( $parsed_args['posts_per_page'] ) ) {
+		$parsed_args['posts_per_page'] = $parsed_args['numberposts'];
 	}
-	if ( ! empty( $r['category'] ) ) {
-		$r['cat'] = $r['category'];
+	if ( ! empty( $parsed_args['category'] ) ) {
+		$parsed_args['cat'] = $parsed_args['category'];
 	}
-	if ( ! empty( $r['include'] ) ) {
-		$incposts            = wp_parse_id_list( $r['include'] );
-		$r['posts_per_page'] = count( $incposts );  // only the number of posts included
-		$r['post__in']       = $incposts;
-	} elseif ( ! empty( $r['exclude'] ) ) {
-		$r['post__not_in'] = wp_parse_id_list( $r['exclude'] );
+	if ( ! empty( $parsed_args['include'] ) ) {
+		$incposts            = wp_parse_id_list( $parsed_args['include'] );
+		$parsed_args['posts_per_page'] = count( $incposts );  // only the number of posts included
+		$parsed_args['post__in']       = $incposts;
+	} elseif ( ! empty( $parsed_args['exclude'] ) ) {
+		$parsed_args['post__not_in'] = wp_parse_id_list( $parsed_args['exclude'] );
 	}
 
-	$r['ignore_sticky_posts'] = true;
-	$r['no_found_rows']       = true;
+	$parsed_args['ignore_sticky_posts'] = true;
+	$parsed_args['no_found_rows']       = true;
 
 	$get_posts = new WP_Query;
-	return $get_posts->query( $r );
+	return $get_posts->query( $parsed_args );
 
 }
 
@@ -3240,9 +3240,9 @@
 		'suppress_filters' => true,
 	);
 
-	$r = wp_parse_args( $args, $defaults );
+	$parsed_args = wp_parse_args( $args, $defaults );
 
-	$results = get_posts( $r );
+	$results = get_posts( $parsed_args );
 
 	// Backward compatibility. Prior to 3.1 expected posts to be returned in array.
 	if ( ARRAY_A == $output ) {
@@ -4937,21 +4937,21 @@
 		'post_status'  => 'publish',
 	);
 
-	$r = wp_parse_args( $args, $defaults );
+	$parsed_args = wp_parse_args( $args, $defaults );
 
-	$number       = (int) $r['number'];
-	$offset       = (int) $r['offset'];
-	$child_of     = (int) $r['child_of'];
-	$hierarchical = $r['hierarchical'];
-	$exclude      = $r['exclude'];
-	$meta_key     = $r['meta_key'];
-	$meta_value   = $r['meta_value'];
-	$parent       = $r['parent'];
-	$post_status  = $r['post_status'];
+	$number       = (int) $parsed_args['number'];
+	$offset       = (int) $parsed_args['offset'];
+	$child_of     = (int) $parsed_args['child_of'];
+	$hierarchical = $parsed_args['hierarchical'];
+	$exclude      = $parsed_args['exclude'];
+	$meta_key     = $parsed_args['meta_key'];
+	$meta_value   = $parsed_args['meta_value'];
+	$parent       = $parsed_args['parent'];
+	$post_status  = $parsed_args['post_status'];
 
 	// Make sure the post type is hierarchical.
 	$hierarchical_post_types = get_post_types( array( 'hierarchical' => true ) );
-	if ( ! in_array( $r['post_type'], $hierarchical_post_types ) ) {
+	if ( ! in_array( $parsed_args['post_type'], $hierarchical_post_types ) ) {
 		return false;
 	}
 
@@ -4968,7 +4968,7 @@
 	}
 
 	// $args can be whatever, only use the args defined in defaults to compute the key.
-	$key          = md5( serialize( wp_array_slice_assoc( $r, array_keys( $defaults ) ) ) );
+	$key          = md5( serialize( wp_array_slice_assoc( $parsed_args, array_keys( $defaults ) ) ) );
 	$last_changed = wp_cache_get_last_changed( 'posts' );
 
 	$cache_key = "get_pages:$key:$last_changed";
@@ -4976,12 +4976,12 @@
 		// Convert to WP_Post instances.
 		$pages = array_map( 'get_post', $cache );
 		/** This filter is documented in wp-includes/post.php */
-		$pages = apply_filters( 'get_pages', $pages, $r );
+		$pages = apply_filters( 'get_pages', $pages, $parsed_args );
 		return $pages;
 	}
 
 	$inclusions = '';
-	if ( ! empty( $r['include'] ) ) {
+	if ( ! empty( $parsed_args['include'] ) ) {
 		$child_of     = 0; //ignore child_of, parent, exclude, meta_key, and meta_value params if using include
 		$parent       = -1;
 		$exclude      = '';
@@ -4988,7 +4988,7 @@
 		$meta_key     = '';
 		$meta_value   = '';
 		$hierarchical = false;
-		$incpages     = wp_parse_id_list( $r['include'] );
+		$incpages     = wp_parse_id_list( $parsed_args['include'] );
 		if ( ! empty( $incpages ) ) {
 			$inclusions = ' AND ID IN (' . implode( ',', $incpages ) . ')';
 		}
@@ -5003,8 +5003,8 @@
 	}
 
 	$author_query = '';
-	if ( ! empty( $r['authors'] ) ) {
-		$post_authors = preg_split( '/[\s,]+/', $r['authors'] );
+	if ( ! empty( $parsed_args['authors'] ) ) {
+		$post_authors = preg_split( '/[\s,]+/', $parsed_args['authors'] );
 
 		if ( ! empty( $post_authors ) ) {
 			foreach ( $post_authors as $post_author ) {
@@ -5058,10 +5058,10 @@
 	}
 
 	if ( 1 == count( $post_status ) ) {
-		$where_post_type = $wpdb->prepare( 'post_type = %s AND post_status = %s', $r['post_type'], reset( $post_status ) );
+		$where_post_type = $wpdb->prepare( 'post_type = %s AND post_status = %s', $parsed_args['post_type'], reset( $post_status ) );
 	} else {
 		$post_status     = implode( "', '", $post_status );
-		$where_post_type = $wpdb->prepare( "post_type = %s AND post_status IN ('$post_status')", $r['post_type'] );
+		$where_post_type = $wpdb->prepare( "post_type = %s AND post_status IN ('$post_status')", $parsed_args['post_type'] );
 	}
 
 	$orderby_array = array();
@@ -5086,7 +5086,7 @@
 		'comment_count',
 	);
 
-	foreach ( explode( ',', $r['sort_column'] ) as $orderby ) {
+	foreach ( explode( ',', $parsed_args['sort_column'] ) as $orderby ) {
 		$orderby = trim( $orderby );
 		if ( ! in_array( $orderby, $allowed_keys ) ) {
 			continue;
@@ -5117,7 +5117,7 @@
 	}
 	$sort_column = ! empty( $orderby_array ) ? implode( ',', $orderby_array ) : "$wpdb->posts.post_title";
 
-	$sort_order = strtoupper( $r['sort_order'] );
+	$sort_order = strtoupper( $parsed_args['sort_order'] );
 	if ( '' !== $sort_order && ! in_array( $sort_order, array( 'ASC', 'DESC' ) ) ) {
 		$sort_order = 'ASC';
 	}
@@ -5134,7 +5134,7 @@
 
 	if ( empty( $pages ) ) {
 		/** This filter is documented in wp-includes/post.php */
-		$pages = apply_filters( 'get_pages', array(), $r );
+		$pages = apply_filters( 'get_pages', array(), $parsed_args );
 		return $pages;
 	}
 
@@ -5151,8 +5151,8 @@
 		$pages = get_page_children( $child_of, $pages );
 	}
 
-	if ( ! empty( $r['exclude_tree'] ) ) {
-		$exclude = wp_parse_id_list( $r['exclude_tree'] );
+	if ( ! empty( $parsed_args['exclude_tree'] ) ) {
+		$exclude = wp_parse_id_list( $parsed_args['exclude_tree'] );
 		foreach ( $exclude as $id ) {
 			$children = get_page_children( $id, $pages );
 			foreach ( $children as $child ) {
@@ -5184,9 +5184,9 @@
 	 * @since 2.1.0
 	 *
 	 * @param array $pages List of pages to retrieve.
 	 * @param array $r     Array of get_pages() arguments.
 	 */
-	return apply_filters( 'get_pages', $pages, $r );
+	return apply_filters( 'get_pages', $pages, $parsed_args );
 }
 
 //
@@ -5184,9 +5184,9 @@
 	 *
 	 * @param array $pages List of pages to retrieve.
-	 * @param array $r     Array of get_pages() arguments.
+	 * @param array $parsed_args     Array of get_pages() arguments.
 	 */
Index: wp-includes/user.php
===================================================================
--- wp-includes/user.php	(revision 43719)
+++ wp-includes/user.php	(working copy)
@@ -1104,13 +1104,13 @@
 
 	$defaults['selected'] = is_author() ? get_query_var( 'author' ) : 0;
 
-	$r = wp_parse_args( $args, $defaults );
+	$parsed_args = wp_parse_args( $args, $defaults );
 
-	$query_args = wp_array_slice_assoc( $r, array( 'blog_id', 'include', 'exclude', 'orderby', 'order', 'who', 'role', 'role__in', 'role__not_in' ) );
+	$query_args = wp_array_slice_assoc( $parsed_args, array( 'blog_id', 'include', 'exclude', 'orderby', 'order', 'who', 'role', 'role__in', 'role__not_in' ) );
 
 	$fields = array( 'ID', 'user_login' );
 
-	$show = ! empty( $r['show'] ) ? $r['show'] : 'display_name';
+	$show = ! empty( $parsed_args['show'] ) ? $parsed_args['show'] : 'display_name';
 	if ( 'display_name_with_login' === $show ) {
 		$fields[] = 'display_name';
 	} else {
@@ -1119,9 +1119,9 @@
 
 	$query_args['fields'] = $fields;
 
-	$show_option_all   = $r['show_option_all'];
-	$show_option_none  = $r['show_option_none'];
-	$option_none_value = $r['option_none_value'];
+	$show_option_all   = $parsed_args['show_option_all'];
+	$show_option_none  = $parsed_args['show_option_none'];
+	$option_none_value = $parsed_args['option_none_value'];
 
 	/**
 	 * Filters the query arguments for the list of users in the dropdown.
@@ -1129,21 +1129,21 @@
 	 * @since 4.4.0
 	 *
 	 * @param array $query_args The query arguments for get_users().
 	 * @param array $r          The arguments passed to wp_dropdown_users() combined with the defaults.
 	 */
-	$query_args = apply_filters( 'wp_dropdown_users_args', $query_args, $r );
+	$query_args = apply_filters( 'wp_dropdown_users_args', $query_args, $parsed_args );
 
 	$users = get_users( $query_args );
 
 	$output = '';
-	if ( ! empty( $users ) && ( empty( $r['hide_if_only_one_author'] ) || count( $users ) > 1 ) ) {
-		$name = esc_attr( $r['name'] );
-		if ( $r['multi'] && ! $r['id'] ) {
+	if ( ! empty( $users ) && ( empty( $parsed_args['hide_if_only_one_author'] ) || count( $users ) > 1 ) ) {
+		$name = esc_attr( $parsed_args['name'] );
+		if ( $parsed_args['multi'] && ! $parsed_args['id'] ) {
 			$id = '';
 		} else {
-			$id = $r['id'] ? " id='" . esc_attr( $r['id'] ) . "'" : " id='$name'";
+			$id = $parsed_args['id'] ? " id='" . esc_attr( $parsed_args['id'] ) . "'" : " id='$name'";
 		}
-		$output = "<select name='{$name}'{$id} class='" . $r['class'] . "'>\n";
+		$output = "<select name='{$name}'{$id} class='" . $parsed_args['class'] . "'>\n";
 
 		if ( $show_option_all ) {
 			$output .= "\t<option value='0'>$show_option_all</option>\n";
@@ -1150,22 +1150,22 @@
 		}
 
 		if ( $show_option_none ) {
-			$_selected = selected( $option_none_value, $r['selected'], false );
+			$_selected = selected( $option_none_value, $parsed_args['selected'], false );
 			$output   .= "\t<option value='" . esc_attr( $option_none_value ) . "'$_selected>$show_option_none</option>\n";
 		}
 
-		if ( $r['include_selected'] && ( $r['selected'] > 0 ) ) {
+		if ( $parsed_args['include_selected'] && ( $parsed_args['selected'] > 0 ) ) {
 			$found_selected = false;
-			$r['selected']  = (int) $r['selected'];
+			$parsed_args['selected']  = (int) $parsed_args['selected'];
 			foreach ( (array) $users as $user ) {
 				$user->ID = (int) $user->ID;
-				if ( $user->ID === $r['selected'] ) {
+				if ( $user->ID === $parsed_args['selected'] ) {
 					$found_selected = true;
 				}
 			}
 
 			if ( ! $found_selected ) {
-				$users[] = get_userdata( $r['selected'] );
+				$users[] = get_userdata( $parsed_args['selected'] );
 			}
 		}
 
@@ -1179,7 +1179,7 @@
 				$display = '(' . $user->user_login . ')';
 			}
 
-			$_selected = selected( $user->ID, $r['selected'], false );
+			$_selected = selected( $user->ID, $parsed_args['selected'], false );
 			$output   .= "\t<option value='$user->ID'$_selected>" . esc_html( $display ) . "</option>\n";
 		}
 
@@ -1195,7 +1195,7 @@
 	 */
 	$html = apply_filters( 'wp_dropdown_users', $output );
 
-	if ( $r['echo'] ) {
+	if ( $parsed_args['echo'] ) {
 		echo $html;
 	}
 	return $html;
@@ -1129,21 +1129,21 @@
 	 *
 	 * @param array $query_args The query arguments for get_users().
-	 * @param array $r          The arguments passed to wp_dropdown_users() combined with the defaults.
+	 * @param array $parsed_args          The arguments passed to wp_dropdown_users() combined with the defaults.
 	 */
